#
# spec file for package google-cloud-sdk
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Look at to pull the tarball
# cloud.google.com/sdk/

Name:           google-cloud-sdk
Version:        140.0.0
Release:        13.1
Summary:        Tools for Google Cloud Services
# Tarball from this location includes alpha and beta command line interfaces
License:        Apache-2.0
Group:          System/Management
Url:            https://console.cloud.google.com/storage/browser/cloud-sdk-release/for_packagers/linux/?authuser=0&pli=1
Source0:        %{name}-%{version}.tar.bz2
Source1:        setup.py
# The dependencies listed do not match with up stream naming and our
# packaging conventions
Patch1:         gcsdk-gsutil-hide-deps.patch
# No self updating possible, thus disable the check for new versions
Patch2:         gcsdk-gsutil-no-self-update-check.patch
# cloud-sdk uses the sokcs implementation, as a proxy to set up configuration
# options for httplib2. In python2 httplib2 supplies it's own socks
# implementation which happens to be compatible with the one one in thrid_party
# in python3 httplib2 depends on using an external socks implementation.
# On 2016-1012 the socks implementation used by openSUSE was PySocks version
# 1.5.6 which does not support PROXY_TYPE_HTTP_NO_TUNNEL
Patch3:         gcsdk-no-http-no-tunnel-proxt.patch
# API change in python-google-apitools
Patch4:         gcsdk-no-batch-limit.patch
# Lost in gsutil development, to be resubmitted upstream
Patch5:         gcsdk-gsutil-use-system-certs.patch
# Dependencies are inconsistent within the tarball
Patch6:         gcsdk-bq-hide-deps.patch
Requires:       kubernetes-client
Requires:       python
Requires:       python-Jinja2
Requires:       python-MarkupSafe
Requires:       python-PyYAML                    >= 3.11
Requires:       python-Pygments                  >= 1.5
Requires:       python-SocksiPy                  >= 1.0
Requires:       python-antlr3_runtime            >= 3.0.1
Requires:       python-argcomplete
Requires:       python-argparse                  >= 1.2.1
Requires:       python-boto                      >= 2.42.0
Requires:       python-chardet                   >= 2.0.1
Requires:       python-crcmod                    >= 1.7
Requires:       python-dnspython                 >= 1.9.4
Requires:       python-docker-py
Requires:       python-dulwich                   >= 0.10.2
Requires:       python-enum34
Requires:       python-fasteners                 >= 0.14.1
Requires:       python-funcsigs                  >= 1.0.2
Requires:       python-gcs-oauth2-boto-plugin    >= 1.14
Requires:       python-gflags                    >= 2.0
Requires:       python-google-api-python-client  >= 0.1.3
Requires:       python-google-apitools           >= 0.5.6
Requires:       python-httplib2                  >= 0.9.2
Requires:       python-ipaddr                    >= 2.1.11
Requires:       python-monotonic                 >= 1.2
Requires:       python-oauth2                    >= 1.5.170
Requires:       python-oauth2client              >= 2.2.0
Requires:       python-oauth2client-gce
Requires:       python-portpicker
Requires:       python-pyasn1                    >= 0.1.9
Requires:       python-pyasn1-modules
Requires:       python-python-dateutil           >= 2.4.2
Requires:       python-python-gflags
Requires:       python-python-mimeparse
Requires:       python-requests                  >= 2.10
Requires:       python-retry_decorator           >= 1.0.0
Requires:       python-rsa                       >= 3.1.2
Requires:       python-ruamel.yaml               >= 0.11.11
Requires:       python-six                       >= 1.9.0
Requires:       python-uritemplate
Requires:       python-urllib3                   >= 1.15.1
Requires:       python-wcwidth
Requires:       python-websocket-client
Provides:       gcutils > 1.13.0
Provides:       gsutils > 3.42
Obsoletes:      gcutils <= 1.13.0
Obsoletes:      gsutils <= 3.42
BuildRequires:  python-setuptools
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
Google Cloud SDK contains tools and libraries that allow you to create and
manage resources on Google Cloud Platform, including App Engine, Compute
Engine, Cloud Storage, Cloud SQL, and BigQuery.

%prep
%setup -q
%patch1
%patch2
%patch3
%patch4
%patch5
%patch6
# The following python packages have independent upstream
mv lib/third_party/{containerregistry,fancy_urllib,gae_ext_runtime,pyu2f} lib
rm -rf lib/third_party
rm -rf lib/tools
cp %{SOURCE1} %{_builddir}/%{name}-%{version}

%build
# The top level lib dir does not become a Python package
rm lib/__init__.py
python setup.py build
pushd platform/gsutil
# We need to get rid of the tests or "regular" operation will load test
# code, ....
rm -rf gslib/tests
rm gslib/commands/test.py
python setup.py build
popd
pushd platform/bq
python setup.py build
popd

%install
# Leave it to Google to set silly permissions, fix it
find . -name "*.html" -exec chmod -x "{}" +
find . -name "*.json" -exec chmod -x "{}" +
find . -name "*_test.py" -exec chmod +x "{}" +
install -d -m 755 %{buildroot}/%{_mandir}/man1
install -m 644 help/man/man1/* %{buildroot}/%{_mandir}/man1
# Remove shebang from files intended for import
#find lib/googlecloudsdk/third_party/appengine -type f | xargs grep -l '#!' | xargs sed -i 1d
# Install gcloud
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
install -d %{buildroot}/%{_bindir}
install -d %{buildroot}/%{_defaultdocdir}/%{name}
install -d %{buildroot}/%{_mandir}
install -d %{buildroot}/%{_sysconfdir}/bash_completion.d
cp completion.bash.inc %{buildroot}/%{_sysconfdir}/bash_completion.d/gcloud.sh
echo "#!/bin/sh" > %{buildroot}/%{_bindir}/gcloud
echo "python %{python_sitelib}/googlecloudsdk/gcloud_main.py \"\$@\"" >> %{buildroot}/%{_bindir}/gcloud
chmod +x %{buildroot}/%{_bindir}/gcloud
# Install gsutil
pushd platform/gsutil
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
# Force extra files into the right location bsc#1054930
# files are in Manifest.in and should be included, but setuptools is
# not playing nice
cp VERSION CHECKSUM %{buildroot}/%{python_sitelib}/gslib/
popd
# Install bigquery
pushd platform/bq
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
popd

%files
%defattr(-,root,root,-)
%doc LICENSE README RELEASE_NOTES
%dir %{python_sitelib}/googlecloudsdk
%dir %{python_sitelib}/google_cloud_sdk-%{version}-py%{py_ver}.egg-info
%dir %{python_sitelib}/surface
%{_mandir}/man*/*
%{_bindir}/gcloud
%{python_sitelib}/googlecloudsdk/*
%{python_sitelib}/google_cloud_sdk-%{version}-py%{py_ver}.egg-info/*
%{python_sitelib}/surface/*
%config %{_sysconfdir}/bash_completion.d/gcloud.sh
# integrated gsutil
%dir %{python_sitelib}/gslib
%dir %{python_sitelib}/gsutil-4.22-py%{py_ver}.egg-info
%dir %{python_sitelib}/test
%{_bindir}/gsutil
%{python_sitelib}/gslib/*
%{python_sitelib}/gsutil-4.22-py%{py_ver}.egg-info/*
%{python_sitelib}/test/*
# integrated bq
%dir %{python_sitelib}/bigquery-2.0.24-py%{py_ver}.egg-info
%dir %{python_sitelib}/discovery
%{_bindir}/bq
%{python_sitelib}/bigquery_*
%{python_sitelib}/bigquery-2.0.24-py%{py_ver}.egg-info/*
%{python_sitelib}/bq.*
%{python_sitelib}/bq_*
%{python_sitelib}/discovery/*
%{python_sitelib}/table_formatter.*
# built in dependency on fancy_urllib, not available as stand alone code stream
%dir %{python_sitelib}/fancy_urllib
%{python_sitelib}/fancy_urllib/*
# built in dependency on gae_ext_runtime, not available as stand alone
# code stream
%dir %{python_sitelib}/gae_ext_runtime
%{python_sitelib}/gae_ext_runtime/*
# built in dependency on containerregistry, not available as stand alone
%dir %{python_sitelib}/containerregistry
%{python_sitelib}/containerregistry/*
# built in dependency on pyu2f, not available as stand alone
%dir %{python_sitelib}/pyu2f
%{python_sitelib}/pyu2f/*

%changelog
* Wed Sep  6 2017 rjschwei@suse.com
- Fix gsutil (bsc#1054930)
  + Force VERSION and CHECKSUM file into the right place, settings from
    MANIFEST.in are being ignored
  + Remove the "gsutil test" command. The test command depends on third_party
    test implementation and is invoked during "regular" operation such
    as cp and ls. Testing should be loaded only for developers
* Tue Feb  7 2017 jengelh@inai.de
- Use the more typical >= operator for version comparisons
- Use find -exec over xargs
* Mon Jan 30 2017 rjschwei@suse.com
- Update to version 140.0.0 (2017/01/18)  (bsc#1002895,bsc#1008328)
  + Remove hidePathMangeling.patch
  + Add gcsdk-gsutil-hide-deps.patch
  + Add gcsdk-gsutil-no-self-update-check.patch
  + Add gcsdk-gsutil-use-system-certs.patch
  + Add gcsdk-no-batch-limit.patch
  + Add gcsdk-no-http-no-tunnel-proxt.patch
  + Add gcsdk-bq-hide-deps.patch
  + Remove disableSelfUpdate.patch, disabled by default from upstream
  + Cloud SDK
  * `gcloud alpha search-help` is now available in alpha.
    Run `gcloud alpha search-help [TERM]` to find gcloud commands whose
    help text contains [TERM].
  + Google Cloud ML
  * `gcloud ml jobs submit training` now supports packages already in Google
    Cloud Storage via the `--packages` flag.
  + Google Cloud Datalab
  * Upgrade the Datalab CLI to the 20170110 build.
  + Google Cloud Debugger
  * The `gcloud debug` command group is now available in GA.
  + Google Container Registry
  * An issue that affected Docker client version parsing during
    `docker-credential-gcr configure-docker` has been fixed.
  + Google Cloud Deployment Manager
  * 'deployment-manager deployments update' can update deployments with a new
    description using --description flag.
  + Emulators
  * The pubsub emulator now accepts web-safe Base64 encoded data.
- From version 139.0.1 (2017/01/12)
  * Fixed crash in `gcloud dataproc clusters create`
  * https://code.google.com/p/google-cloud-sdk/issues/detail?id=1464
- From version 139.0.0 (2017/01/11)
  + Breaking Changes
  * (Google Cloud Logging) The default value of the `--unique-writer-identity`
    flag to `gcloud beta logging sinks create` and
    `gcloud beta logging sinks update` is now true. Please consult the
    documentation before using these commands.
  * (Google Cloud Logging) Remove 'struct' option from `gcloud logging write`.
    Use 'json' instead
  * (Google Cloud Logging) `logging beta metrics create` and
    `logging beta metrics update` commands have changed their flags and
    importantly now use Logging V2 filter syntax. See the help for more
    information.
  * (Google App Engine) Flexible deployments now skip files matching
    `node_modules` and `.git` by default, but no longer skip other hidden
    files by default. Standard deployments are not changing.
  * (Google Compute Engine)
    `gcloud compute target-pools set-backup --backup-pool` and
    `gcloud compute project-info set-usage-bucket --bucket` flags now warn
    if you provide an empty argument; use `--no-backup-pool` and
    `--no-bucket instead`.
  * (Google Cloud Bigtable) Removed `gcloud alpha bigtable` command group;
    please use `gcloud beta bigtable` for all Cloud Bigtable operations.
  * (Stackdriver Debugger) Added a `--location` option to several
    `gcloud beta debug` commands, to separate out the processing of resource
    IDs from filename patterns. These commands now take only resource IDs as
    positional parameters.
  + Google Cloud Datalab
  * Added the command-line tool for Google Cloud Datalab in the Cloud SDK;
    call it via the `datalab` script.
  + Google Cloud Key Management Service
  * Added the `gcloud beta kms` commands for key management.
  + Google Cloud Logging
  * Add `--billing-account` flag to `gcloud logging read`
  * gcloud beta logging metrics list/describe now output the version of the
    filter associated with the metric
  + Google Cloud ML
  * The `gcloud beta ml jobs submit training` now takes a `--scale-tier` flag.
  * Support gzipped TFRecord file type for
    `gcloud beta ml jobs submit prediction`.
  + Google App Engine
  * (Google App Engine) Fixed bug with `gcloud app instances describe`.
  - -service and --version flags are now required.
  * `gcloud beta app deploy` now uses multi-threading rather than
    multi-processing for file uploads; if you've been seeing issues on
    Windows, please try the `beta` command out.
  * `gcloud app versions migrate` is now GA.
  * `gcloud app instances delete` is now GA.
  * Added `gcloud beta app operations` commands.
  * Added `gcloud beta app instances delete` command.
  + Google Compute Engine
  * `gcloud beta compute images create` now has a `--guest-os-features`
    flag for enabling specific OS supported features.
  * Use the new scopes format (see `--help` for deetails) for
  - `gcloud alpha compute instances create`
  - `gcloud alpha compute instances create-from-container`
  - `gcloud alpha compute instance-templates create`
  - `gcloud alpha compute instance-templates create-from-container`
  - `gcloud beta compute instances create`
  - `gcloud beta compute instance-templates create`
  * Add `--custom-extensions` flag to:
    `gcloud alpha compute instances create`,
    `gcloud alpha compute instances set-machine-type`, and
    `gcloud alpha compute instance-templates create`
  + Google Compute Engine (Networking)
  * The `--host` flag for `gcloud alpha compute url-maps
    invalidate-cdn-cache` is now available in the GA version of the command.
  + Stackdriver Debugger
  * Fixed log view URLs in the debug logpoints commands to use the V2 query
    syntax.
  + Google Service Management
  * `--validate-only` flag added to `gcloud service-management deploy` command
  + Google Cloud Functions
  * The `--trigger-params` flag has been renamed to `--trigger-path`
    (the `path=` specifier is no longer necessary). The old flag has been
    deprecated and will be removed or `gcloud alpha functions deploy`.
  * Restore `gcloud alpha functions get-logs` command.
  * Restore deprecated flags `--trigger-topic`, `--trigger-bucket`,
    `--source`, `--bucket`, and `--trigger-gs-uri` to `gcloud alpha
    functions deploy` command.
  + Google Container Engine
  * Update Google Container Engine's kubectl from version 1.4.6 to 1.5.1.
  + Google Cloud Bigtable
  * The `cbt` command line tool component is now available. See:
    https://cloud.google.com/bigtable/docs/go/cbt-reference
  + Google Cloud Datastore
  * `gcloud datastore create-indexes` and `cleanup-indexes` are now GA
  + Google Container Registry
  * `docker-credential-gcr` has been upgraded to v1.3 and now supports Docker
    client v1.14 credential helpers. `docker-credential-gcr` will now
    preferentially act as a credential helper (as opposed to credential
    store) on Docker client versions 1.14+. Update (or install) the
    `docker-credential-gcr` component and run `docker-credential-gcr
    configure-docker` to configure your Docker client to use
    `docker-credential-gcr` to authenticate operations on your GCR
    repositories.
  + Google Cloud Deployment Manager
  * Added labels support to the
    `gcloud alpha deployment-manager deployments create` and `update` commands
    (via the `--labels` and `--{update,remove}-labels` flags respectively).
  * Introduce new syntax `key:val,foo:bar` for `--properties` flag in all
    `gcloud deployment-manager` commands. The old `key=val,foo=bar` syntax is
    deprecated.
- From version 138.0.0 (2016/12/14)
  + Cloud SDK
  * Introduce --(no-)force-key-file-overwrite flags to all gcloud commands
    using SSH key files. These new flags control overwrite behavior when
    SSH key files are broken. Without these flags, interactive sessions will
    ask for confirmation before regenerating key files. Old non-interactive
    behavior (permissive) is deprecated and will be removed in 6 months. To
    preserve old behavior in your scripts, use new flag
  - -force-key-file-overwrite (though this is discouraged).
  * Credential store format for service accounts has changed. Your
    credentials will get auto-upgraded to new format upon usage; however, if
    gcloud is downgraded to previous version those credentials will not be
    usable and users will have to reactivate their service account.
  + Google Cloud ML
  * `gcloud beta ml jobs submit training` is now blocking by default. Use the
    `--async` flag to finish immediately after job submission.
  + Google Compute Engine
  * `gcloud compute instances create` creates instance with no scopes by
    default if project has no default service account.
  * `compute target-ssl-proxies list` deprecated `--regex` and names argument.
    Please use `--filter` flag instead.
  * `gcloud compute connect-to-serial-port` allows for interactive
    connections to the serial port for instances.
  * Promote `compute instances set-scopes` command from alpha to beta.
  + Google App Engine
  * Java SDK updated to 1.9.48. For more details, please see
    https://cloud.google.com/appengine/docs/java/release-notes
  * Python SDK updated to 1.9.49. For more details, please see
    https://cloud.google.com/appengine/docs/python/release-notes
  * `gcloud app describe` is now GA.
  * Added `gcloud beta app instances delete`, which deletes a specific
    App Engine instance.
  * Added `gcloud beta app versions migrate`.
  * Added support for `env: flex` (Flexible Environment) instances to
    `gcloud app instances enable-debug` and `gcloud app instances disable-debug`.
  * Added support for skip_files in Flexible Environment deployments.
  + Google Container Engine
  * Users can create clusters/nodepools with node autoupgrade enabled in
    Beta by adding `--enable-auto-upgrade`. Please refer to
    `gcloud beta container clusters create --help` and
    `gcloud beta container node-pools create --help` for more details.
  * node-pool upgrades can now be rolled back using the
    `gcloud alpha container node-pools rollback <pool-name>` command.
    See `gcloud alpha container node-pools rollback --help` for more details.
  + Google Cloud Container Builder
  * Container Builder timeouts are now unlimited (with a default of ten
    minutes), and can be specified with the --timeout flag.
  + Google Cloud Dataflow
  * The `gcloud dataflow jobs` command group now has the following commands
    in GA: cancel, describe, drain, list, show
  + Google Cloud Functions
  * Remove `gcloud alpha functions get-logs` command.
  * Remove deprecated flags --trigger-topic --trigger-bucket --source --bucket
  - -trigger-gs-uri from `gcloud alpha functions deploy` command.
- From version 137.0.1 (2016/12/08)
  + Google Cloud ML
  * `gcloud beta ml jobs submit training`: Fix crash when `--packages` was not
    specified.
- From version 137.0.0 (2016/12/07)
  + Google Cloud Functions
  * Add `gcloud alpha functions deploy` `--trigger-provider`,
    `--trigger-event`, `--trigger-resource` and `--trigger-params` flags.
  * Add `gcloud alpha functions event-types list` command.
  + Google Cloud ML
  * The `gcloud beta ml models versions` command group has been moved to
    `gcloud beta ml versions`. The old commands still work, but are
    deprecated.
  * The `--origin` flag for the `gcloud beta ml versions create` command now
    accepts local file paths in addition to Google Cloud Storage (`gs://`)
    paths.
  * `gcloud beta ml jobs training`: `--packages` now takes a comma-separated
    list instead of a space-separated list.
  + Google Compute Engine
  * Internal Load Balancing is now available in GA.
  * It is no longer allowed to pass an empty scope in
    `gcloud compute instances create --scopes` flag.
  + Google Container Engine
  * `gcloud container images describe` has some breaking changes to its
  - -format=JSON output.
  + Google Service Management
  * The gcloud service-management surface is now available in the GA and beta
    release tracks. Please use `gcloud service-management` instead of
    `gcloud beta service-management`.
- From version 136.0.0 (2016/12/01)
  + Cloud SDK
  * `gcloud config get-value` is now GA.
  + Google Cloud Service Management
  * Add `gcloud beta service-management undelete`.
  + Google Container Engine
  * Add `gcloud beta container image describe` to list container analysis
    data.
  * Update Google Container Engine's kubectl from version 1.4.4 to 1.4.6.
  + Google Cloud Container Builder
  * `gcloud container builds ...` are now GA.
  + Google Cloud Resource Manager
  * `gcloud organizations ...` are now GA.
  * Removed `gcloud organizations update`.
  + Google Cloud ML
  * Add `gcloud beta ml local predict` to do local prediction.
  * Deprecate '--instances' flag in `gcloud beta ml predict`.
  + Google App Engine
  * `gcloud app instances describe` is now GA.
  * `gcloud app services describe` is now GA.
  * `gcloud app logs read` will now show request logs by default as well as
    stdout, stderr, and crash.log.
  * Add `gcloud beta app describe`, which prints information about the
    current App Engine application.
  * `gcloud beta app deploy` can now deploy go apps, without the use of
    `aedeploy` or `goapp deploy`. Both App Engine Standard and Flexible
    environments are supported. If you are using `runtime: custom` with
    `aedeploy`, you will need to vendor your dependencies into the app
    directory manually.
  * Deprecated the configuration property `app/gsutil`. Affected users are
    warned during `gcloud app deploy` with instructions on how to update
    their configuration appropriately.
  * The App Engine flexible environment now defaults to Python 3.5 when
    Python 3 is requested. To temporarily revert to Python 3.4, specify
    `python_version: 3.4` in the `runtime_config` stanza of your
    [`app.yaml`](https://cloud.google.com/appengine/docs/flexible/python/configuring-your-app-with-app-yaml).
  * Updated app-engine-go component to the 1.9.48 SDK.
  + Google Compute Engine
  * Add `--service-label` flag to `gcloud alpha compute forwarding-rules
    create`.
  + Cloud Tools for Powershell
  * Add cmdlets to manage Cloud Storage ACLs.
  + Google Cloud Deployment Manager/Runtime Configuration
  * Fixed `gcloud deployment-manager deployments describe` when resource
    expansion fails.
  + Bigtable Emulator
  * Bigtable emulator now supports `column_range_filter`.
  + Google Cloud Dataproc
  * Add `--service-account` flag to `gcloud dataproc clusters create`.
- From version 135.0.0 (2016/11/16)
  + Google Cloud Service Management
  * `gcloud service-management deploy` command now supports providing
    multiple service configuration or API specification inputs
    simultaneously. This change allows creating .proto and YAML based
    configurations for gRPC services.
  + Google Container Engine
  * Change the `gcloud container list-tags` command to support user-specified
    filters on occurrences and exposes a column summarizing vulnerability
    information.
  + Google Cloud Resource Manager
  * `gcloud organizations update` is now deprecated.
  + Google Cloud Deployment Manager/Runtime Configuration
  * Runtime configuration variables can now be set and retrieved using text
    values.
  + Bigtable Emulator
  * Now supports macOS Sierra.
  + Google App Engine
  * The App Engine flexible environment now includes Python 3.5
    support (beta). To preview this runtime, specify `python_version: 3.5`
    in the `runtime_config` stanza of your
    [`app.yaml`](https://cloud.google.com/appengine/docs/flexible/python/configuring-your-app-with-app-yaml) file.
  * Added the `gcloud beta app services describe` command, which prints
    information about a given service.
- From version 134.0.0 (2016/11/09)
  + Cloud SDK
  * `gcloud info --run-diagnostics` flag is now available to diagnose common
    installation and local network issues.
  * `gcloud init` now has a `--skip-diagnostics` flag.
  + Google AppEngine
  * App Engine Java SDK updated to 1.9.46.
    Please visit the following release notes for details:
    https://cloud.google.com/appengine/docs/java/release-notes
  * Added `gcloud app create` command, which creates an App Engine app in the
    current project.
  * Added `gcloud app regions list` command, which lists support for
    App Engine Standard and Flexible environments for each geographical
    region.
  * `gcloud app deploy` now offers to create an App Engine app
    interactively, if the current project does not have an app yet.
  + Google Cloud BigQuery
  * Add support for specifying a null marker when loading data. See the
    `null_marker` flag within the `load` command.
  + Google Compute Engine
  * `gcloud compute instance-groups managed delete` shows clean error message
    instead of bare exception on attempt to delete zonal and regional Managed
    Instance Groups in one gcloud invocation. Old behavior was to accept and
    invoke such request and then fail on waiting for operation complete.
  * Remove OpenSUSE as a default image option. OpenSUSE images are still
    available in the opensuse-cloud project.
- From version 133.0.0 (2016/11/02)
  + Google Cloud Container Builder
  * `gcloud alpha container builds` promoted to beta. The following has
    changed:
  * The 'create' command is now called 'submit'.
  * The 'stream-logs' command is now called 'log', and will only stream
    the log if the '--stream' flag is used. Otherwise, it will print
    only the log contents available at the time the command was run.
  The alpha commands will remain, as is, until at least March of 2017.
  + Google Compute Engine
  * regional instance groups are now GA.
    `gcloud compute instance-groups managed`
  * Customer-Supplied Encryption Keys (CSEK) for image creation is now GA. See
    https://cloud.google.com/compute/docs/disks/customer-supplied-encryption
    for details.
  + Google Container Engine
  * Update kubectl to version 1.4.4.
- From version 132.0.0 (2016/10/26)
  + Breaking Changes
  * (Cloud SDK-wide) Command line flag abbreviations are no longer supported.
  * (Cloud SDK-wide) Python 2.6 is no longer supported by the Cloud SDK and
    commands may not function correctly when run under an Python 2.6
    interpreter. Please update your Python installation to 2.7 to ensure
    compatibility.
  * If you have a 2.7 interpreter on your system that is not the default,
    you can use the CLOUDSDK_PYTHON environment variable to point to it.
  * The last version of the SDK that supports Python 2.6 is 131.0.0,
    which can be downloaded from our archive:
    <https://cloud.google.com/sdk/downloads#earlier_versions>
  * (Google Compute Engine/Google Cloud Source Repositories): Google Cloud
    Source Repositories scope no longer added by default on instance creation.
  * (Stackdriver Debugger) Changed the default to true for the `--all-users`
    option on `gcloud beta debug logpoints list` command.
  + Google Cloud Storage
  * Update gsutil component to 4.22
    See: <https://github.com/GoogleCloudPlatform/gsutil/blob/v4.22/CHANGES.md>
  + Google Compute Engine
  * Allow specifying both `--network` and `--subnet` for the same network
    interface card.
  + Google Cloud Dataproc
  * Jobs and clusters now support labels on creation
  * Jobs and clusters now support filtering by labels and state
  + Google Container Engine
  * Google Container Engine cluster upgrade operations can now be cancelled
    using the `gcloud alpha container operations cancel` command.  See
    `gcloud alpha container operations cancel --help` for more details.
  + Cloud Tools for Powershell
  * Fix a bug where the module is not picking up the active user credentials
    correctly.
  * Make `New-GcsObject` `-ObjectName` parameter optional when uploading a
    file.
  * Add ability to pipeline `GcsObject` to `Write-GcsObject` cmdlet.
- From version 131.0.0 (2016/10/19)
  + Cloud SDK
  * Added PowerShell provider for Google Cloud Storage; allows navigation of
    Google Cloud Storage buckets as if they were a local file system.
    When using Cloud Tools for PowerShell `cd` into gs:\ and type `dir` to
    begin. Learn more at
    https://cloud.google.com/tools/powershell/docs/backup.
  * App Engine updated to 1.9.45. Java SDK updated to 1.9.44.
    Please visit the following release notes for details:
    https://cloud.google.com/appengine/docs/java/release-notes
  * `gcloud config configurations create` will now automatically activate
    specified empty configuration. Use `gcloud config set` to populate its
    properties.
  + Google Cloud Compute
  * The Customer-Supplied Encryption Keys (CSEK) feature for Google Compute
    Engine image creation is now available in the beta release track. See
    https://cloud.google.com/compute/docs/disks/customer-supplied-encryption
    for details.
  + Google Container Engine
  * Added support for for creating new clusters and nodepools on preemptible
    VM instances in Beta by adding `--preemptible`. See
    `gcloud beta container clusters create --help` and
    `gcloud beta container node-pools create --help` for more details.
  * Fixed a bug in `gcloud alpha container clusters update` that
    prevented disabling cluster autoscaling. Cluster autoscaling
    can now be disabled by running:
    `gcloud alpha container clusters update --disable-autoscaling`
  * Update kubectl to version 1.4.1.
  + Google Cloud BigQuery
  * Added support for setting labels on query jobs.
    Example usage: `bq query --label "foo:bar" "select 123"`.
    The `show` command outputs any labels set on a job.
  + Google Source Repository
  * Change the Cloud Source Repositories scope given by default to
    Google Compute Engine Instances and Instance Templates to read_only
    from full control.
- From version 130.0.0 (2016/10/12)
  + Breaking Changes
  * Breaking change to --network-interface in `alpha compute instances
    create`, and `alpha compute instance-images create` commands. By default
    interfaces will have ephemeral IP (was: no external ip).
  + Google AppEngine
  * App Engine: The `gcloud app deploy` command no longer blocks when
    stopping the previous version; this should speed up deployment times.
    Instructions for checking the status of the stop-version operation are
    included in the command output.
  * Support ramdisk volumes in App Engine flexible environments Alpha.
  + Google Cloud Functions
  * Add `alpha functions regions list` command.
  + Google Cloud ML
  * Change '--instances=' to
    '(--json-instances=, --instances= | --text-instances=)' to allow
    `gcloud beta ml predict` to read files in UTF-8 encoded text format.
  + Google Cloud Platform Projects
  * Add the `gcloud alpha projects create` command.
  + Google Compute Engine
  * Add new key to --network-interface in `alpha compute instances create`,
    and `alpha compute instance-images create` commands: no-address.
  * Make flag --network-interface visible in `alpha compute instances create`,
    and `alpha compute instance-templates create` commands.
  + Google Container Engine
  * Fix a bug in `gcloud beta container images list-tags`.
  * Add support for kubernetes labels on new clusters and nodepools by passing
    `--node-labels=label1=value1,label2=value2...`. See
    `gcloud container clusters create --help` and
    `gcloud container nodepools create --help` for more details and
    examples.
- From version 129.0.0 (2016/10/05)
  + Google Cloud Bigtable
  * `gcloud alpha bigtable` commands are deprecated and will be removed in
    release 134.0.0. All users should migrate to `gcloud beta bigtable`
    commands.
  + Google Cloud ML
  * Add `gcloud beta ml jobs stream-logs` JOB [--allow-multiline-logs]
    [--polling-interval=POLLING_INTERVAL; default="60"] [GLOBAL-FLAG ...]
    to show logs from a running Cloud ML job.
  + Google Compute Engine
  * The --replacement flag is no longer required in the
    `gcloud compute images deprecate` command.
  * Add --create-disk flag to `gcloud alpha compute instances create`.
  * Add --create-disk flag to `gcloud alpha compute instance-templates
    create`.
  + Google Container Engine
  * Can now specify the cluster-version when creating Google Container Engine
    clusters.
  * Update kubectl to version 1.4.0.
  + Google Container Registry
  * `docker-credential-gcr` bug fixed.
  + Go SDK
  * Update Go SDK component to use 20160927 release, based on Go 1.6.3.
  + Stackdriver Logging
  * Added commands to manage logs-based metrics in Stackdriver Logging.
- From version 128.0.0 (2016/09/28)
  + Breaking Changes
  * The `gcloud auth application-default` commands are now in GA.
    `gcloud auth login` no longer writes Application Default Credentials, use
    `gcloud auth application-default login` instead.
  + Google AppEngine
  * Java apps that have no app.yaml file are now auto-detected based on a
    WEB-INF/appengine-web.xml file when launching the dev_appserver.
  * Fixed timestamp processing issue
    (https://code.google.com/p/google-cloud-sdk/issues/detail?id=1121) in
    `gcloud app logs read`.
  + Google Cloud Functions
  * Added the `--memory` flag to `gcloud alpha functions deploy` to allow
    configuration of amount of memory available during function execution.
  + Google Cloud ML
  * Added `gcloud beta ml local train` command which runs user code
    locally and injects the environment variables necessary for running
    distributed TensorFlow jobs in subprocesses.
  * `gcloud beta ml jobs submit training` now takes a path to a python
    package, and either (1) builds from the setup.py file at the package
    root, or (2) generates a setup.py file and builds the package. It then
    uploads the generated tar.gz archives to Google Cloud Storage.
  + Google Compute Engine
  * Internal load balancing is now in beta.
  * Cloud Source Repositories control scope is now included in the list
    of default scopes granted to newly created instances and instance
    templates.
  * Added multi-nic support to `gcloud alpha compute instances create` and
    `gcloud alpha compute instance-templates create`.
  + Google Container Engine
  * Can now create temporary clusters with all kubernetes alpha features
    enabled using `gcloud alpha container clusters create
  - -enable-kubernetes-alpha`.
  * Added support for kubernetes labels on new clusters and nodepools by
    passing
    `--node-labels=label1=value1,label2=value2...`. See
    `gcloud alpha container clusters create --help` and
    `gcloud alpha container nodepools create --help` for more details and
    examples.
  + Google Container Repository
  * Added the ability to configure where (and in which order)
    docker-credential-gcr searches for Google Container Registry
    credentials. Run `docker-credential-gcr config --help` for more details.
- From version 127.0.0 (2016/09/21)
  + Google BigQuery
  * New load/query option in BigQuery client to support schema update
    within a load/query job.
  * New query option in BigQuery client to specify query parameters in
    Standard SQL.
  + Google Cloud Dataproc
  * `gcloud dataproc clusters create` flag
    `--preemptible-worker-boot-disk-size`
    can be used to specify future preemptible VM boot disk size.
  + Google Container Engine
  * Update kubectl to version 1.3.7.
  + Google Cloud ML
  * New `gcloud beta ml predict` command to do online prediction.
  * New `gcloud beta ml jobs submit prediction` command to submit batch
    prediction job.
  + Google Cloud SQL
  * New arguments to beta sql instances create/patch commands for Cloud SQL
    Second Generation instances:
  * `--storage-size` Sets storage size in GB.
  * `--maintenance-release-channel` Sets production or preview channel for
    maintenance window.
  * `--maintenance-window-day` Sets day of week for maintenance window.
  * `--maintenance-window-hour` Sets hour of day for maintenance window.
  * `--maintenance-window-any` (patch only) Clears maintenance window
    setting.
- From version 126.0.0 (2016/09/14)
  + Breaking changes
  * The HTTP error messages for these command groups have changed to a common
    format:
  * `gcloud dns`
  * `gcloud genomics`
  * `gcloud logging`
    Some command groups have not changed yet. That should happen in the next
    release. You can use `--log-http` to see the details of all HTTP
    requests and responses on the standard error.
  + Google Compute Engine
  * Add `--connection-draining-timeout` flag to `gcloud compute
    backend-services {create,update}` commands.
  * Added `gcloud alpha compute instance-groups managed update-instances` and
    `stop-proactive-update-instances` commands.
  + Google Cloud Debugger
  * The `gcloud beta debug source gen-repo-info-file` command, which
    generates repository information files for the Stackdriver Debugger,
    is now available.
  + Google Container Registry
  * The `gcloud container images` command group is now available in the beta
    release track.
  + Cloud SDK
  * Added `core/custom_ca_certs_file` property to allow use of a custom CA
    certificate file.
  + Emulators
  * Cloud Datastore emulator now supports proto-over-HTTP and JSON for
    the v1 API. This version of the emulator resolves the deserialization
    issues in 123.0.0.
- From version 125.0.0 (2016/09/07)
  + Google BigQuery
  * `gcloud alpha bigquery` is no longer available.  To use BigQuery, use
    the `bq` tool shipped with the Cloud SDK.
  + Google Compute Engine
  * Add support to change the default service account on a Compute Engine
    project (alpha release) via the following command:
    `gcloud alpha compute project-info set-default-service-account`
  * Support multiple network interface cards in
    `gcloud alpha compute instances create` command.
  * Add `gcloud alpha compute instances set-scopes` command.
  + Google Container Engine
  * Update kubectl to version 1.3.6.
  + Google Container Repository
  * Released bug fixes for docker-credential-gcr as v1.0.1, please rerun
    `docker-credential-gcr configure-docker` after updating.
  + Google Cloud Logging
  * `gcloud logging create` and `gcloud logging update` echo back the writer
    identity associated with the sink.
  + Google Cloud Dataflow
  * The Dataflow CLI is now in Beta.
  + Google Cloud Deployment Manager
  * `gcloud deployment-manager manifests describe` with no manifest
    specified will show the latest manifest of the given deployment.
  + Emulators
  * `gcloud beta emulators datastore start` now defaults to the new
    version of the emulator which supports Cloud Datastore API v1 and
    v1beta3 over gRPC, proto-over-HTTP, and JSON-over-HTTP.
- From version 124.0.0 (2016/08/31)
  + Breaking Changes
  * Creating a Global Backend Service in Compute Engine will warn you if
    you don't use --global. In the future this will be required.
  * Major changes were made to `gcloud alpha dataflow` commands. See
    Google Cloud Dataflow section for more information
  + Google App Engine
  * Added endpointscfg.py to the app-engine-python component.
  * Skipped modules during upload will now be logged at INFO level instead of
    WARN.
  + Google Cloud Dataflow
  * Changes to `gcloud alpha dataflow` commands:
  * Changed the `jobs list` command now has a "status" filter. This
    change is from the JobsV1B3 API. You can now use the API's filter
    request as either "all", "terminated", or "active".
  * Added the `logs list` command. This dumps the log messages created
    from the workflow. Please see the help docs for more information.
  * Renamed `metrics tail` to `metrics list`.
  * Renamed `metrics list` --origin flag to --source. This can be either
    "user" for custom-made aggregates or "service" otherwise. This
    defaults to "all".
  * Added `metrics list` --transform flag. This filters all metrics that
    prefix regex matches the argument.
  * Removed `jobs list` --job-name flag.
  * Added `jobs list` --uri flag.
  + Cloud Tools for Powershell
  * Add Google Cloud Sql and Google Cloud Dns powershell cmdlets.
  + Google Cloud Deployment Manager
  * `deployment-manager deployments create` with a template file will copy
    the outputs specified in the schema to the generated config file.
  + Google Cloud Functions
  * Add alpha  functions logs read command
  + Google Container Repository
  * docker-credential-gcr (GCR's Docker credential helper) has been added
    as an optional component for GCR customers running Docker client v1.11
    or newer. Run `gcloud components install docker-credential-gcr`
    followed by `docker-credential-gcr configure-docker` in order to
    configure Docker. You may then use Docker normally, without any gcloud
    interaction at all (e.g. `docker pull gcr.io/myproject/myimage`)
  + Google Container Engine
  * Update kubectl to version 1.3.5.
  + Google Compute Engine
  * Added `gcloud compute instances stop` --discard-local-ssd flag.
  * Added windows-sql-cloud project to the default public image list.
  + Cloud SDK
  * `gcloud config get-value` is now available in the BETA release track.
  + Emulators
  * Cloud Datastore emulator now supports proto-over-HTTP and JSON
    for the v1 API.
  + Cloud SQL
  * New commands added to beta:
  * `gcloud beta sql backups create`
  * `gcloud beta sql backups create`
  * `gcloud beta sql instances failover`
  * New flags for `gcloud beta sql instances create`:
  * --failover-replica-name
  * --replica-type
  * --storage-auto-increase
  * --storage-type
  * New flags for `gcloud beta sql instances patch`:
  * --storage-auto-increase
  * --no-storage-auto-increase
- From version  122.0.0 (2016/08/24)
  + Google App Engine
  * The `gcloud beta app regions list` command is now available. It
    shows support for the standard and flexible environments for each
    geographical region.
  * `gcloud app versions describe` now shows more extensive information
    about the deployed version, including the container used for
    App Engine Flexible.
  * Built-in versions will no longer appear when listing App Engine
    versions (`gcloud app versions list`).
  + Cloud SDK
  * Users can now make logs garbage collection optional by changing the
    value of the `core/max_log_days` property to 0.
  * The `gsutil` component has been upgraded to version 4.21.
  + Google Cloud Machine Learning
  * Added `gcloud alpha ml jobs submit training` command to start a
    Cloud ML training job.
  + Google Compute Engine/Networking
  * `compute networks switch-mode` and `compute networks expand-ip-range`
    commands are now in beta.
  + Google Container Engine
  * Image Type selection for `gcloud container` commands is now GA.
  + Google Cloud Deployment Manager
  * `gcloud deployment-manager deployments` will now display `INTENT`
    when applicable.
  + Emulators
  * A bug causing the rejection of unpadded base64-encoded bytes data in the
    Pub/Sub emulator (INVALID_ARGUMENT: "Payload isn't valid for request")
    has been fixed.
- From version  122.0.0 (2016/08/17)
  + Google App Engine
  * Added `gcloud beta app instances describe`, which shows information
    about a running App Engine Flexible instance.
  * Add new flags to `gcloud alpha functions deploy`, hide flags that
    are being replaced with new flags, log a warning when someone uses
    a flag to be replaced:
  * *--bucket    * to be replaced by *--stage-bucket*.
  * *--source    * to be replaced by *--local-path
  * (for code in local file system)
  * --source-path    * (for code in Google Code Storage).
  * *--trigger-gs-uri    * to be replaced by *--trigger-bucket*.
  + Cloud SDK
  * `gcloud init` now has an opt-in for listing all user projects, which
    could be in the hundreds. The user can now to opt-in to see all projects,
    or they can just type in a known project.
  + Google Cloud Machine Learning
  * Add `gcloud alpha ml models versions` group to manage Cloud ML model
    versions.
  * Add `gcloud alpha ml models` group to manage Cloud ML models
  * Add `gcloud alpha ml jobs` group to manage Cloud ML training and
    prediction jobs.
  + Google Cloud Genomics
  * The `gcloud genomics pipelines run` command now uses the default Compute
    Engine zone property if the *--zones    * flag is not specified.
  + Google Cloud Pub/Sub
  * Fixed error handling bug in `gcloud beta pubsub subscriptions create`
    (https://code.google.com/p/google-cloud-sdk/issues/detail?id=1017).
  + Google Compute Engine
  * Enable *--health-checks
  * flag for the `gcloud beta compute backend-services`
    `create` and `update` commands.
  + Google Container Builder
  * *RepoSource    * is now available as a source for builds.
  * *BuildSteps    * now respect arbitrary dependencies on each other
    as defined by the `waitFor` field.
  + Google Container Engine
  * Update kubectl to version 1.3.4.
- From version  121.0.0 (2016/08/10)
  + Google App Engine
  * Cloud SDK dev_appserver.py supports running App Engine Standard Go
    applications.
  * `gcloud app instances disable-debug` now deletes the instance rather
    than restarting it. New instance(s) may spawn based on the app's
    scaling settings.
  + Google Cloud Dataproc
  * Added the `--preemptible-worker-boot-disk-size` flag to
    `gcloud dataproc clusters create`.
  + Google Compute Engine
  * `gcloud compute backend-services` session affinity flags have been
    promoted from beta to GA.
  + Google Container Engine
  * Changed the `container/use_client_certificate` property default value to
    `false`. This makes the `gcloud container clusters create` and
    `gcloud container clusters get-credentials` commands configure
    `kubectl` to use Google OAuth2 credentials by default instead of the
    legacy client certificate.
  + Google Cloud Dataflow
  * Added the `gcloud alpha dataflow jobs drain` command. The `drain` command
    takes a streaming job and stops receiving new data from the sources. It
    then processes the buffered data. For more information please see the
    documentation for stopping a running pipeline at
    <https://cloud.google.com/dataflow/pipelines/stopping-a-pipeline>.
  + Google Cloud DNS
  * Fix for issue reported in:
    <http://stackoverflow.com/questions/38636010/removing-dns-entries-with-gcloud>.
  + Stackdriver Error Reporting
  * Added `gcloud beta error-reporting events report` command for reporting
    errors.
- From version  120.0.0 (2016/08/03)
  + Deployment Manager
  * `deployment-manager resources list` will show INTENT when the
    resource STATE is `IN_PREVIEW`.
  * `deployment-manager deployments describe` will show output values in
    addition to listing the resources.
  + Emulators
  * Added a `gcloud beta emulators bigtable env-init` command to export
    environment variables required to communicate with the bigtable emulator.
  * The PubSub emulator now correctly starts the push loops when creating
    a push subscription.
  + Google Cloud DNS
  * `gcloud dns` now supports CAA records.
  + Google Cloud Storage
  * Update gsutil component to 4.20.
    See: <https://github.com/GoogleCloudPlatform/gsutil/blob/v4.20/CHANGES.md>
  + Google Compute Engine/Networking
  * `gcloud alpha compute instance-groups managed wait-for-stable`
    command waits until all `current_action` fields are set to none and
    there are only no `pending_actions` in managed instance group.
  * `gcloud compute xpn` commands now available in the alpha release track.
    These commands configure cross-project networking.
  * `gcloud compute networks subnets {get,set}-iam-policy` commands now
    available in alpha.
  + Google Container Engine
  * Update kubectl to 1.3.3.
- From version  119.0.0 (2016/07/27)
  + Google BigQuery
  * Added support for dataset labels. See:
    <https://cloud.google.com/bigquery/docs/labeling-datasets> for more
    details.
  * Now sending progress output to stderr and query output to stdout.
    This fixes
    <https://code.google.com/p/google-cloud-sdk/issues/detail?id=780>.
  + Google Cloud SDK
  * `gcloud auth login` will stop writing application default credentials
    in a future release. See:
    <https://developers.google.com/identity/protocols/application-default-credentials#toolcloudsdk> for more information.
  * Command line flag abbreviations are now deprecated and produce warning
    messages. Flag abbreviations will be completely disabled in release
    130.0.0. This pre-empts the problem of future flag additions making
    some flag abbreviations ambiguous, possibly breaking scripts.
  + Google Cloud SQL
  * Added the `gcloud beta sql users` command group with commands that enable
    management of users on Cloud SQL instances.
  + Google Cloud Platform Projects
  * `gcloud alpha projects update` now support labels.
  + Google Container Engine
  * Added the `delete` command to the `gcloud alpha container images` command
    group.
- From version  118.0.0 (2016/07/20)
  + Emulators
  * There is a new `gcloud beta emulators start bigtable` command for
    starting a Cloud Bigtable emulator.
  + Google Compute Engine/Networking
  * `gcloud alpha compute backend-services` and `forwarding-rules` commands
    now support the internal load balancing scheme. Please use
    `--load-balancing-scheme=internal` flag when creating these resources.
    In addition `gcloud alpha compute forwarding-rules create` supports
    `--backend-service` flag to allow forwarding to internal load balancers.
  * Beta release of `compute connect-to-serial-port` command for
    Interactive Serial Console support. See
    http://cloud.google.com/compute/docs/instances/interacting-with-serial-console for details.
  + Google Container Engine
  * Bump kubectl from 1.2.4 to 1.2.5.
  + SQL
  * `gcloud beta sql instances create` supports new database type MYSQL_5_7.
  + Windows support
  * Beta launch of Google Cloud PowerShell. PowerShell cmdlets for managing
    Google Cloud Storage and Google Compute Engine.
    For more information see
    https://googlecloudplatform.github.io/google-cloud-powershell.
- From version  117.0.0 (2016/07/13)
  + Google Compute Engine
  * Regional Managed Instance Groups commands are now in beta.
  * `target-ssl-proxies` commands are now in beta.
  * Connection-based load balancing commands are now in beta.
  * Added `--connection-draining-timeout` flag to
    `gcloud beta compute backend-services` `create` and `update` commands.
  * `health-checks` command group is now in beta.
  + Google Container Engine
  * Local SSDs are now supported for clusters via the `--local-ssd-count`
    flag (in beta).
  * Added `--additional-zones` flag to `gcloud beta container clusters
    update`.
  + Google Container Builder
  * The `gcloud alpha container builds create` command now supports using
    JSON or YAML config files to configure builds, using the `--config` flag.
- From version  116.0.0 (2016/06/29)
  + Breaking Changes
  * `gcloud alpha dataflow list-messages` datetime values are now
    displayed in ISO 8601 format: 2015-01-15T12:31:07 ('T' separating the
    date and time components).
  + Google App Engine
  * The `gcloud app` surface is now available in the GA and beta release
    tracks. Please use `gcloud app` instead of `gcloud preview app`
    (some features only available in the beta release track).
  * Add `gcloud app open-console` command, which opens the App Engine
    dashboard in a web browser.
  + Google Cloud Datastore emulator
  * The Cloud Datastore emulator can accept an IPv6 address for the
    `--host-port` argument.
  * Cloud Datastore emulator no longer fails when trying to load an
    index.yaml file.
  + Google Container Builder
  * The `gcloud alpha container builds` command group creates and manages
    builds using the Google Container Builder service. See
    https://cloud.google.com/container-builder/docs/ for API documentation.
  + Google Cloud Dataproc
  * Added `--preemptible-worker-boot-disk-size` flag, which allows
    configuration of preemptible worker boot disk, to `gcloud beta dataproc
    clusters create`.
  + Google BigQuery
  * New query option in BQ client to specify a limit on bytes billed for the
    query.
  + Google Cloud Bigtable
  * Added `gcloud beta bigtable instances` group to manage Bigtable
    instances.
  * Added `gcloud beta bigtable clusters` group to manage Bigtable clusters
    within instances.
  * Known issue: `gcloud beta bigtable instances create` is an asynchronous
    operation by default and will not block with or without the `--async`
    flag.
- From version  115.0.0 (2016/06/22)
  + Breaking Changes
  * (Google Compute Engine) The `debian-7` and `debian-7-backports` image
    aliases have been removed, as Debian 7 has reached end-of-life
  * (Google Compute Engine) The `--port-range` flag in the `gcloud compute
    forwarding-rules create` command has been deprecated; please use the
    `--ports` flag instead. At this time only consecutive ports can be
    specified.
  * (Google Compute Engine) `gcloud alpha compute rolling-updates` commands
    have been deprecated and removed.
  * (Google Container Engine) The `--wait` flag for the `gcloud container
    clusters` command group is now deprecated; please use the `--async` flag
    instead.
  + Cloud SDK
  * Users will now be prompted to set Cloud SDK proxy properties if network
    issues are detected while running `gcloud init`.
  + Google Compute Engine
  * `gcloud compute backend-services {create,update} --enable-cdn` flag
    has been promoted from beta to GA.
  * `gcloud compute url-maps invalidate-cdn-cache` has been promoted
    from beta to GA.
  * The `--remote-traffic-selector` flag in `gcloud compute vpn-tunnels
    create`, which allows specifying a list of CIDR blocks to be used
    during IKE\IPsec traffic selectors negotiation, is now available in
    the GA release track.
  + Google App Engine
  * Add `gcloud preview app versions describe` command.
  + Deployment Manager
  * (beta only) deployment-manager now supports rollbacks with the
    `--manifest-id` flag: `gcloud beta deployment-manager deployments update
    deployment-name --manifest-id=MANIFEST-ID`
  + Docker
  * `gcloud docker` now respects the `$DOCKER_CONFIG` environment variable
  + Emulators
  * The Cloud Datastore emulator now has an `env-unset` command which
    prints the commands to unset any environment variables set by running
    the commands in the output of the `env-init` command.
- From version  114.0.0 (2016/06/15)
  + Breaking Changes
  * (Google Compute Engine) Deprecated the use of image aliases. Please use
    image families instead. See https://cloud.google.com/compute/docs/images
    for more details.
  * (Google App Engine) Removed the deprecated and unused `--force` flag for
    `gcloud app deploy`.
  * (Google Cloud Debugger) Removed `gcloud alpha debug` command group;
    debug commands are now accessible solely using `gcloud beta debug`.
  + Google Compute Engine
  * The Customer-Supplied Encryption Keys (CSEK) feature for Google Compute
    Engine disks is now available in the GA release track. See
    https://cloud.google.com/compute/docs/disks/customer-supplied-encryption
    for more details.
  * Added autocompletion for the URL map name in
    `gcloud compute url-maps invalidate-cdn-cache`.
  * Added `gcloud alpha compute networks switch-mode` command.
  * Added `gcloud alpha compute networks subnets expand-ip-range` command.
  * Added `--remote-traffic-selector` flag, which allows specifying a list
    of CIDR blocks to be used during IKE\IPsec traffic selectors
    negotiation, to `gcloud beta compute vpn-tunnels create`
  * Fixed `gcloud compute routes list` command to display vpn-tunnel as
    `NEXT_HOP`.
  + Google App Engine
  * Parallelized source file uploads in `gcloud preview app deploy` for
    increased speed. To revert to the old behavior in event of a problem,
    please run `gcloud config set app/num_file_upload_processes 1`
    and report an issue here:
    https://code.google.com/p/google-cloud-sdk/issues/list
  * Google App Engine components updated to 1.9.38.
    Please visit the following release notes for details:
  * Python - https://cloud.google.com/appengine/docs/python/release-notes
  * Java - https://cloud.google.com/appengine/docs/java/release-notes
  * Added support for Managed VMs instances in
    `gcloud preview app instances enable-debug` and
    `gcloud preview app instances disable-debug`.
  + Docker
  * Fixed a bug where Windows users experienced docker authentication issues
    when the `%%HOME%%` variable was set and differed from `%%USERPROFILE%%`
  + Emulators
  * Fixed behavior of pub/sub emulator subscription topic names when their
    respective topics are deleted. They should now be set to
    `_deleted-topic_`.
- From version  113.0.0 (2016/06/08)
  + Cloud SDK
  * gcloud now uses Internet Explorer proxy configuration settings when on
    Windows, or MacOSX SystemConfiguration proxy settings on Mac, if the
    gcloud configurations `proxy/*` are not set.
  + Google Compute Engine
  * `gcloud compute ssh` no longer generates keys when invoked with
  - -plain flag.
  * `gcloud compute routers` is now GA.
  + Google Genomics
  * `gcloud genomics pipelines run` command supports passing "inputs" and
    "outputs" as repeated parameters.
- From version  112.0.0 (2016/06/01)
  + Cloud SDK
  * Updated error messages for `gcloud projects` surface.
  * `gcloud docker` commands now take less time to execute when the
    Docker client is not configured to use a credential helper.
  + Google App Engine
  * The `--docker-build` flag and related `app/docker_build` property,
    as well as `app/use_cloud_build` property have been deprecated and will
    be removed in a future release. By default, Docker images are built
    remotely using Google Container Builder. To perform a Docker build on
    a different host, you can run:
    docker build -t gcr.io/project/service.version .
    gcloud docker push gcr.io/project/service.version
    gcloud preview app deploy --image-url=project/service.version
  + Google Compute Engine
  * Added `--licenses` flag to `gcloud compute images create`.
  + Google Container Engine
  * Fixed bug where only 16-bit kubectl was installed on Windows.
    Now Installs 32 and 64-bit.
  + Google Genomics
  * `gcloud alpha genomics datasets/callsets` name argument is a flag,
    instead of positional.
  * `gcloud alpha genomics pipelines run` command now accepts "zones"
    command-line argument.
  * `gcloud alpha genomics datasets restore/update` and
    `variantsets delete/describe` now take string IDs instead of ints.
  + Deployment Manager
  * `gcloud deployment-manager deployments describe` output only reports
    errors once, includes status for resources, and includes more useful
    fields.
- From version  111.0.0 (2016/05/25)
  + Google App Engine
  * `gcloud docker` commands are now less verbose during the authentication
    operation.
  + Google Container Engine
  * `gcloud container clusters update` command now GA.
  * `gcloud container node-pools` commands are now GA.
  + Google Compute Engine
  * Enabled Strict Host Key Checking for SSH connections (after the first
    connection) to instances. Also adds a new flag to `gcloud compute ssh`
    called `--strict-host-key-checking` to control the StrictHostKeyChecking
    option.
  * Add support for customer-supplied encryption keys to `gcloud beta compute
    instances start`. (in beta track)
  * Implemented backend-service connection based balancing mode.
  + Google Service Registry
  * Launched `gcloud alpha service-registry`. (alpha track)
    Users will need to sign up
    (https://docs.google.com/forms/d/11SfJGB3LUGgT_aSMlVzWoJ0ec2fHKwk0J4e-zTNw0Bs/viewform?edit_requested=true)
    before enabling this API in their projects.
  + Deployment Manager
  * Added `gcloud alpha deployment-manager runtime-configs`. Alpha
    commands for Deployment Manager's Runtime Config API.
  + Emulators
  * Adds a `--legacy` flag to gcloud beta emulators datastore. The flag
    is set by default and maintains existing behavior with support for
    Cloud Datastore API v1beta2. Passing `--no-legacy` uses a new version
    of the Cloud Datastore Emulator which supports Cloud Datastore API
    v1beta3 over gRPC, JSON, and proto-over-HTTP. The default behavior of
    the legacy flag will change in a future release.
  + Organizations
  * Launched `gcloud alpha orgranizations`. (alpha track)
- From version  110.0.0 (2016/05/18)
  + Google IAM
  * The `gcloud iam` command group is now available in GA. The
    `gcloud beta iam` will still be available for several more releases.
  + Google App Engine
  * Fixed issue with the `--docker-build=local` flag in the
    `gcloud preview app deploy` command with docker version 1.10+. Note
    that local Docker builds with Docker version 1.11 will still fail when
    using the new Docker external credentials; please downgrade to the
    plain credential store.
    https://code.google.com/p/google-cloud-sdk/issues/detail?id=802
  + Google Container Engine
  * `gcloud beta container` commands (e.g. `container create`) now support
    specifying ImageTypes.
  * The `gcloud container clusters list` command now sorts the clusters
    based on zone and then on cluster name.
  * The `gcloud container clusters create` command now allows specifying
  - -max-nodes-per-pool (default 1000) to create multiple node pools for
    large clusters.
  + Google Compute Engine
  * The `gcloud compute backend-services` backend commands now support
  - -instance-group-zone and --instance-group-region to qualify instance
    group specifically. Before --zone, --region was used to qualify all
    resource arguments, where as now it is used to qualify backend service.
  + Google Genomics
  * The `genomics variantsets create` command now supports the --name and
  - -description flags.
  * The `genomics variantsets delete` command displays the name of the
    variant set before prompting the user to delete it.
  * The genomics `variantsets describe/list` commands display variant set
    names and descriptions.
  + Emulators
  * The Google Cloud Datastore emulator supports a new environment variable
    for client library configuration.
  * The Google Cloud Datastore emulator flag --store-on-disk has been fixed to
    accept a false value using --no-store-on-disk. Previously,
  - -store-on-disk=False could be specified but wasn't respected.
  + Debug
  * The `The gcloud debug` command group is now in Beta.
  + Misc.
  * The Cloud SDK Windows installer is now dual signed SHA1 and SHA256. The
    executable is signed with both authenticode and RFC3161 signatures.
  * The winkeygen.exe executable is also now dual signed, like above.
- From version  109.0.0 (2016/05/11)
  + Google App Engine
  * Google App Engine components updated to 1.9.37.
  * Please visit the following release notes for details:
  * Python -
    https://cloud.google.com/appengine/docs/python/release-notes
  * Java - https://cloud.google.com/appengine/docs/java/release-notes
  * Fixed issue with failed uploads in gcloud preview app-deploy
    (https://code.google.com/p/google-cloud-sdk/issues/detail?id=784).
  * Deprecated --server flag for app commands; its use is unsupported.
  + Google Compute Engine
  * Removed the `gcloud alpha compute autoscaler` command group.
  * Removed deprecated `gcloud compute backend-services add-backend` --group
    flag in favor of --instance-group.
  * `gcloud compute copy-files` now exits with the return code of the called
    `scp` process.
  * Added support for customer-supplied encryption keys to the
    `gcloud beta compute disks snapshot` command.
  * Remove google-containers from default gcloud public image project.
  + Google Container Engine
  * Fixed bug listing clusters with no node pools.
  * `gcloud container resize` command now supports multi-zone clusters.
  + Google Error Reporting
  * Added the `gcloud beta error-reporting events delete` command to cleanup
    Stackdriver Error Reporting data.
- From version  108.0.0 (2016/05/04)
  + Breaking Changes
  * The `gcloud preview app modules get-logs` command is now deprecated.
    Please use the new command `gcloud preview app logs read` instead.
  + Google App Engine
  * Fixed a bug which caused `gcloud preview app deploy` to fail when run
    from a git directory.
  + Google Cloud SDK
  * Deprecated user property files (~/.config/gcloud/properties) will
    no longer be read by gcloud.  If you are not already using
    `configurations`, your properties will be automatically migrated for
    you.  No action is required on your part.
  * The `--format` flag now supports four more transforms: `extract`, `join`,
    `slice`, and `split`.
  + Google Cloud Debugger
  * Added the `gcloud alpha debug snapshots wait` command.
  + Google Compute Engine
  * The `gcloud alpha compute instance-groups managed list-instances` command
    output now includes the `INSTANCE_TEMPLATE` and `STATUS` columns.
  + Google Container Engine
  * Update kubectl to v1.2.3
  + Google Genomics
  * `gcloud alpha genomics variants describe/delete/update` commands now
    accept non-integer variant IDs.
- From version  107.0.0 (2016/04/27)
  + Google Compute Engine
  * Enable cursor ("start") support for get-serial-port-output in Beta.
  * Add tail-serial-port-output in Beta.
  * Image families are now in General Availability (GA).
  + Google App Engine
  * Google App Engine components updated to 1.9.36.
  * Please visit the following release notes for details:
  * Python - https://cloud.google.com/appengine/docs/python/release-notes
  * Java - https://cloud.google.com/appengine/docs/java/release-notes
  + Deployment Manager
  * Creating and updating Deployments will now display output values
    in addition to listing the resources.
  + Google Container Engine
  * `gcloud container clusters resize` now allows specifying a node pool.
  + Cloud Debugger
  * Added `gcloud alpha debug` command surface to allow control of the
    Cloud Debugger from the command line.
  + Google BigQuery
  * BQ support for partitioned tables.
- From version  106.0.0 (2016/04/20)
  + Breaking Changes
  * Python 2.6 support in the Cloud SDK is deprecated and releases will stop
    supporting Python 2.6 on September 1, 2016.  Please update your Python
    installation to 2.7 to ensure compatibility with future Cloud SDK
    versions.
  * `gcloud preview app modules` commands are now deprecated (see "Google App
    Engine" section for more details).
  * `module` parameter in application .yaml files is now deprecated
    (see "Google App Engine" section for more details).
  * `--format` printer legend attributes are now deprecated (see "Cloud SDK"
    section for more details).
  + Cloud SDK
  * The --format printer legend attributes are deprecated and will be
    removed in release 124.0.0. The legend attribute docs have been removed.
  * The gcloud compute, functions, genomics, logging, and projects list
    commands now  support the `--filter` flag.
  + Google Cloud Storage
  * Update gsutil component to 4.18
    (https://github.com/GoogleCloudPlatform/gsutil/blob/v4.19/CHANGES.md)
  + Google App Engine
  * App Engine "modules" are being renamed to "services".
  * The `gcloud preview app modules` commands are now deprecated (except
    `gcloud preview app modules get-logs`). Please use the just-added
    `gcloud preview app versions`, `gcloud preview app services`, and
    `gcloud preview app instances` commands instead.
  * The 'module' parameter in application .yaml files is deprecated; please
    use 'service' instead.
  * Fixed `MaxRetrialsException` for `gcloud preview app deploy` of standard
    (not MVM or flexible) App Engine apps with `.git` directory present
    (<https://code.google.com/p/google-cloud-sdk/issues/detail?id=727>).
  * Fixed bug in `gcloud preview app deploy` where `--docker-build=local`
    did not work when `app/use_cloud_build` was enabled.
  + Google Compute Engine
  * Add `--no-creation-retries` flag to `compute instance-groups managed
    resize` command in alpha and beta.
  + Google Container Engine
  * Fix bug that caused kubectl component to be missing from components
    list on Windows.
  * `gcloud container clusters create` now allows specifying multiple zones
    within a region for your cluster's nodes to be created in.
  * Update kubectl to v1.2.2
- From version  105.0.0 (2016/04/13)
  + Breaking Changes
  * `health-checks` commands for protocol HTTP2 have been removed.
  * Rename the `alpha compute url-maps` `invalidate-cache` and
    `list-cache-invalidations` subcommands to `invalidate-cdn-cache` and
    `list-cdn-cache-invalidations`, respectively.
  + Cloud SDK
  * Suppress progress tracker animations if not outputting to a terminal.
  * `gcloud components list` now supports the `--filter` flag and queries
    like:
    `gcloud components list --filter=id:app-engine-java
  - -format="value(state.name)"`
  + Google Compute Engine
  * Promote Cloud CDN functionality from alpha to beta.
  + Google App Engine
  * File uploads during gcloud preview app deploy have been improved. If
    you have any trouble, you can revert to the old behavior with
    `gcloud config set app/use_gsutil true`.
- From version  104.0.0 (2016/04/06)
  + Cloud SDK
  * `gcloud init` no longer offers to clone
    [Google Cloud Repositories]
    (https://cloud.google.com/source-repositories/docs/).
    Please use `gcloud source repos clone` at any time after running
    `gcloud init`.
  + Google Compute Engine
  * `gcloud beta compute` commands now support image families.
  + Google App Engine
  * Users of `gcloud preview app deploy` can set the timeout for the
    Container Builder service using the app/cloud_build_timeout
    property.
  + Google Container Engine
  * kubectl component is now available for Windows (64-bit only).
  * `gcloud alpha container clusters update` now allows enabling/disabling
    addons for Container Engine clusters via `--update-addons` flag.
  * `gcloud container clusters create` now supports disabling
    HPA and Ingress controller addons via `--disable-addons` flag.
  + Google Genomics
  * `gcloud alpha genomics variants import` now supports configurable variant
    info field merging via the info_merge_config command line flag.
- From version  103.0.0 (2016/03/30)
  + Google Cloud Storage
  * Update gsutil component to 4.18
    (https://github.com/GoogleCloudPlatform/gsutil/blob/v4.18/CHANGES.md)
  + Google App Engine
  * Add fingerprinting support for PHP applications. You can now run
    `gcloud preview app gen-config` to auto-generate the necessary
    configuration for deploying PHP applications to the App Engine
    Flexible Environment.
  + Google Container Engine
  * gcloud container clusters create|get-credentials will warn/error
    respectively if the HOME env var isn't set. The variable
    is required to store kubectl credentials (kubeconfig).
  + Google Compute Engine
  * Enable support for: gcloud compute disks resize.
- From version  102.0.0 (2016/03/22)
  + Breaking Changes
  * The `gcloud alpha container nodepools` commands have been renamed to
    `node-pools`. Functionality and parameters haven't changed.
  * `gcloud beta iam list-grantable-roles` now returns a list of roles
    instead of a dictionary with a single key 'roles' with the value of
    a list of roles.
  * `gcloud config configuration describe` output has changed to include the
    configuration `name` and `is_active` fields. All configuration
    properties are now part of the `properties` field.
  + Cloud SDK
  * --format=json and --format=yaml now list resource attributes with
    null values.
  + Google App Engine
  * Use of the Google Container Builder service is now enabled by default for
    all managed VMs deployments.
    This change may require you to enable the Container Builder API. Visit
    https://console.developers.google.com/apis/api/cloudbuild.googleapis.com/overview?project=*PROJECT_ID*;
    to enable it, where *PROJECT_ID    * is your current project ID.
  * Updated Google App Engine components to 1.9.34.
    Please visit the following release notes for details:
  * Python - https://cloud.google.com/appengine/docs/python/release-notes
  * Java - https://cloud.google.com/appengine/docs/java/release-notes
  + Google Compute Engine
  * Added `gcloud compute backend-services` session affinity commands.
  * Added `gcloud compute http-health-checks` and `https-health-checks`
    commands.
  * Added `gcloud alpha compute target-ssl-proxies` commands.
  * Extended `gcloud compute forwarding-rules` to support
    `target-ssl-proxies`.
  + Google Container Engine
  * `gcloud container clusters list` will output a warning if there
    were zones for which it could not retrieve results.
  * Updated kubectl to version 1.2.0.
- From version  101.0.0 (2016/03/16)
  + Billing
  * Added [`gcloud alpha billing`]
    (https://cloud.google.com/sdk/gcloud/reference/alpha/billing/)
    command surface.
  + Google App Engine
  * App Engine components updated to 1.9.34. Please visit
    <https://cloud.google.com/appengine/docs/python/release-notes> for the
    Python release notes and
    <https://cloud.google.com/appengine/docs/java/release-notes>
    for the Java release notes.
  + Google BigQuery
  * Updated the `bq` tool to version v2.0.24. Also includes fix for
    <https://code.google.com/p/google-cloud-sdk/issues/detail?id=632>.
- From version  100.0.0 (2016/03/09)
  + Breaking Changes
  * `gcloud preview app deploy` deployments that promote the new version to
    receive all traffic will stop the previous version by default.
    To keep the previous behavior, pass the `--no-stop-previous-version`
    flag, or run the following command:
    $ gcloud config set app/stop_previous_version false
  + Cloud SDK
  * Providing no argument for list- and dict-type flags now results in a
    warning. Instead, please explicitly provide an empty string value. For
    instance, `gcloud command --flag` becomes `gcloud command --flag ''`
    (for list- and dict-type flags only).
  + IAM
  * Added `gcloud beta iam list-grantable-roles` command for given
    cloud resource.
  + Google App Engine
  * Fixed `WindowsError: [Error 32]` in the `gcloud preview app deploy`
    command on Windows. Fixes
    <https://code.google.com/p/google-cloud-sdk/issues/detail?id=554>.
  + Google Container Engine
  * Added node pool support to enable heterogeneous clusters (alpha).
- From version  99.0.0 (2016/3/2)
  + Breaking Changes
  * Support for the deprecated workspace configurations feature has been
    removed. If you are using gcloud in a workspace, those properties will
    no longer be read.  See `gcloud topic configurations` for information
    on how to use configurations instead.
  + Cloud SDK
  * Enable gcloud to run in Cygwin 64 bit environments.
  * Fail gracefully on unreadable Google Compute Engine credential file.
    Fixes
    <https://code.google.com/p/google-cloud-sdk/issues/detail?id=460>.
  + Google App Engine
  * App Engine components updated to 1.9.33. Please visit
    <https://cloud.google.com/appengine/docs/python/release-notes> for
    the Python release notes and
    <https://cloud.google.com/appengine/docs/java/release-notes> for the Java
    release notes.
  * Added `gcloud preview app browse` command.
  * Fixed a race condition that caused errors while deploying App Engine
    Managed VM applications.
  * Fixed a TLS-related error during gcloud preview app deploy. Alleviates
    the problem in
    <https://code.google.com/p/google-cloud-sdk/issues/detail?id=559>.
  + Google Compute Engine
  * `routers` surface moved to beta and is now accessible via
    `gcloud beta compute routers`
  + Google Cloud Dataproc
  * Add `--subnet` flag to `gcloud dataproc clusters create`.
  + Google Cloud Genomics
  * `genomics alpha operations cancel` assumes the `operations/` prefix
    if not present.
  + Google Cloud Storage
  * Update gsutil component to 4.17
- From version  98.0.0 (2016/2/24)
  * Release 95.0.0 introduced a bug that generated corrupt keys for
    Windows gcloud compute ssh|copy-files. Any keys generated on Windows
    between 95.0.0 and 97.0.0 inclusive are rejected by ssh servers.
    `gcloud compute` has been changed to:
  * Fix the winkeygen Windows key generator.
  * Recognize corrupt Windows keys and automatically regenerate them.
  * Fixed
    [#538](https://code.google.com/p/google-cloud-sdk/issues/detail?id=538).
    Users should no longer get "gsutil ImportError: No module named google"
    errors.
  + Google App Engine
  * MySqldb "latest" version changed from 1.24b4 to 1.2.5.
  + Emulators
  * Improves Pub/Sub emulator's ability to handle requests concurrent with
    HTTP pull requests.
  * The Pub/Sub emulator attempts to detect and inform users when an
    unsupported API version is used.
  * The Pub/Sub emulator now correctly handles absolute URIs in HTTP/Json
    requests.
  + Windows support
  * Google Cloud SDK no longer needs Python installed when using the Windows
    Installer. The SDK for Windows comes with Python bundled.
- From version  97.0.0 (2016/2/17)
  + Breaking Changes
    `gcloud alpha compute routers` now requires manual configuration of
    interfaces
  + Google Compute Engine
  * Added flag `--advertised-route-priority` to `gcloud alpha compute
    routers create`
  * Added support for regional instance groups in alpha
  + Google App Engine
  * Ruby runtime now uses the Rack "deployment" environment, instead
    of "none"
  + Google Container Engine
  * Added `--master` flag to `gcloud container clusters upgrade`
- From version  96.0.0 (2016/2/10)
  + Google App Engine
  * Google App Engine components updated to 1.9.32. Please visit the
    following release notes for details:
    Python - https://cloud.google.com/appengine/docs/python/release-notes
    Java - https://cloud.google.com/appengine/docs/java/release-notes
  * The `gcloud preview app gen-config` command now offers to
    automatically update the runtime field in app.yaml if necessary.
  + IAM
  * The `gcloud beta iam` command group has launched.
  + Emulators
  * The Pub/Sub emulator now supports Gzip-encoded requests.
  + Google Compute Engine
  * The gcloud compute copy-files|scp commands on Windows now treat path
    arguments with a drive prefix as local files.
  + Configurations
  * The `config configurations delete` command now takes multiple
    configuration names.
  + Containers
  * kubectl is updated to v1.1.7.
  * Bugfix on the `gcloud container clusters get-credentials` when run
    from a client without edit permissions.
  + Misc. Changes
  * The default floating point output format precision is 6. Exponent
    notation is used for abs(n) < 1e-04 and abs(n) >= 1e+09.
  * The arrow and page up/down/home/end keys now work in the Windows help
    pager.
- From version  95.0.0 (2016/2/3)
  + Breaking Changes
  * Use `gcloud compute networks create --mode=legacy` to create non-subnet
    networks.
  + Google Compute Engine
  * `gcloud compute copy-files` and `gcloud compute ssh` on Windows now use
    standard PuTTY plink.exe, pscp.exe and putty.exe. A standalone
    winkeygen.exe generates PuTTY and ssh compatible keys. The Windows
    PuTTY executables are up to date at version 0.66.
  + Google Compute Engine subnets
  * Added `gcloud compute networks subnets`.
  * Added `--mode` flag to `gcloud compute networks create`.
  * Added `--subnet` flag to `gcloud compute instances create` and
    `gcloud compute instance-templates create`.
  * Added `--local-traffic-selector` flag to `gcloud compute vpn-tunnels
    create`.
  + Google App Engine
  * Added support for streaming logs when the `use_cloud_build=1` property
    is set.
  * Moved the nodejs install script into the docker image.
  + Projects
  * `gcloud projects update|undelete|delete` have been moved to beta.
  + gcloud --format
  * Added nested table formatting by
    `--format="table(field1,listField2:format=FORMAT-STRING)"` where
    _FORMAT-STRING_ can be any format (json, table, ...).
    Try: `gcloud compute instances list
  - -format="table[box](name, disks:format='table[no-heading]
    (deviceName:sort=1, kind)')"`
  * Added list field aggregation formatting (similar to nested formatting) by
    `--format="table(listField2:format=FORMAT-STRING)"`. When the main table
    has no columns each nested format is aggregated into a single list.
    Try: `gcloud compute instances list
  - -format="table(disks:format='table[box](deviceName:sort=1, kind)')"`
- From version  94.0.0 (2016/1/27)
  + Google Compute Engine
  * Added `gcloud alpha compute url-maps list-cache-invalidations` command.
  + Google App Engine
  * Google App Engine components updated to 1.9.31. Please visit the
    following release notes for details:
    Python - https://cloud.google.com/appengine/docs/python/release-notes
    Java - https://cloud.google.com/appengine/docs/java/release-notes
  * Added `--runtime` flag to `gcloud preview app gen-config` to specify
    a runtime when a directory identifies as multiple runtimes. This flag
    can be used in conjunction with `--custom`.
  + Google Container Engine
  * `gcloud container cluster describe` and `list` commands now notify
    the user when their cluster versions are about to go out of support or
    are unsupported.
  + Google Cloud Logging
  * `gcloud beta logging write` and `gcloud beta logging logs delete`
    commands now use the V2beta1 API. The `gcloud beta logging write`
    command now uses the global resource descriptor (which translates to
    "custom.googleapis.com" service in V1).
  + Cloud Dataproc
  * `gcloud beta dataproc clusters create` now supports `--tags` and
    `--metadata` flags to set instance tags and metadata on all instances
    in the Dataproc cluster.
  + PubSub Emulator
  * A new --host flag can be used to specify the address the emulator
    should bind as. The flag can be left unspecified, set to "localhost",
    a hostname, or an explicit IP address.
  + Projects
  * Added commands `get-iam-policy`, `set-iam-policy`,
    `add-iam-policy-binding`, and `remove-iam-policy-binding` for the
    `gcloud beta projects` surface.
  * Added the `gcloud projects list` command that can be used to list
    projects.
- From version  93.0.0 (2016/1/20)
  * kubectrl upgraded to 1.1.4.
  * `gcloud beta dataproc cluster create` now supports `--properties` flag
    to set properties for installed packages.
  * Datastore emulator's `DATASTORE_LOCAL_HOST` environment variable
    changed to `DATASTORE_EMULATOR_HOST`.
  * `gcloud source repos clone` now supports `--dry-run` flag to show
    equivalent git command.
- From version  92.0.0 (2016/1/13)
  * Because of the rollback of 91.0.0, this release contains all of the
    changes from 91.0.0 in addition to the changes listed below.
  + Breaking Changes
  * `gcloud preview app deploy`
  * Changed deployments to set the deployed versions to receive all
    traffic for their modules by default.
    To keep the old behavior (traffic split remains the same), use the
    `--no-promote` flag or run
    `gcloud config set app/promote_by_default true`.
    Note that your old versions are still running, and must be stopped
    manually. This behavior will change in a future release.
  * Removed deprecated `--set-default` flag.  Please use `--promote`
    instead.
  * `gcloud preview app deploy`: Removed deprecated `--env-vars` flag.
  * The output of the `gcloud preview app modules list` command has been
    changed to include the traffic split percentage instead of the 'default
    version' field.
  * Removed deprecated `gcloud preview app modules cancel-deployment`
    command.
  * This command is no longer necessary due to recent improvements in the
    Deployment API.
  * Removed deprecated `gcloud preview app modules download` command.
  * This command is no longer necessary due to recent improvements in the
    Deployment API.
  * Removed deprecated `gcloud preview app run` command. Please use
    `dev_appserver.py` instead.
  * Changed behavior of the `--zone`/`-z` flag in the
    `gcloud dns record-sets` command group. This flag can no longer precede
    the command. For instance,
    `gcloud dns record-sets -z=mz list` will not work, but
    `gcloud dns record-sets list -z=mz` will.
  * Changed `--password-file` option for `sql instances set-root-password`;
    password now does not include trailing newline from password file. This
    matches the documented behavior, but not the previous behavior.
    (Fixes https://code.google.com/p/google-cloud-sdk/issues/detail?id=419)
  * Removed `meta/active_configuration` from the results of
    `gcloud config list` since it is not a property that can be set. You
    can continue to use the `gcloud config configurations` commands to
    view and manage your configurations.
  + Cloud SDK
  * Added `gcloud config` proxy settings. Users can configure `gcloud` to
    use a proxy via the following settings:
  * `gcloud config proxy/address`
  * `gcloud config proxy/password`
  * `gcloud config proxy/port`
  * `gcloud config proxy/type`
  * `gcloud config proxy/username`
  * Added `alpha` and `beta` components to Debian packages.
  * Removed unused config properties: `app/hosted_registry`, `app/host`,
    `app/admin_host`, `app/api_host`.
  + Google Cloud Logging
  * Migrated to
    [v2beta1](https://cloud.google.com/logging/docs/api/introduction_v2) API
    release.
  * Moved `gcloud beta logging sinks` commands to `v2beta1`.
  * Added `gcloud beta logging resource-descriptors` command to display
    supported resources from various services.
  * Added `gcloud beta logging read` command to retrieve log entries
    using filters.
  + Google Container Engine
  * Added `gcloud container clusters resize` for resizing Container Engine
    clusters.
  * Added notifications when node upgrades are available to `gcloud container
    cluster describe` and `list` commands.
  + Google App Engine
  * Fixed bug where initial deployments using `--image-url` failed.
  * Changed `gcloud preview app modules set_default` command to use the App
    Engine Admin API.
  * Changed `gcloud preview app modules list` command to use the App Engine
    Admin API.
- From version  91.0.1 (2015/12/16)
  * The Cloud SDK has been rolled back to 90.0.0.
- From version  91.0.0 (2015/12/16)
  + Breaking Changes
  * Deprecated command group `gcloud compute replica-pools` has been removed.
  * Deprecated command group `gcloud compute resource-views` has been removed.
  * App Engine API is now the only supported method for deploying in the
    `gcloud preview app deploy` command.
  + Google App Engine
  * `DEPLOYABLES` argument for `gcloud preview app deploy` is now
    optional. If not given, the command defaults to `app.yaml` in the
    current directory; if that is not found, it attempts to automatically
    generate necessary configuration files (such as app.yaml) in the
    current directory before deployment.
  * `--force` argument to `gcloud preview app deploy` is now deprecated
    and will be removed in a future release.
  + Container
  * `gcloud container` commands that poll long running operations
    (e.g create, delete, upgrade) now display progress details when
    available.
- From version  90.0.0 (2015/12/09)
  * Cloud SDK release version scheme has changed. Patch version is now
    treated as a major release version which corresponds to SDK weekly
    releases. Any updates/fixes to released version will increment
    minor/patch version number going forward.
  + Breaking Changes
  * The deprecated flag --clear-target-pool has been removed from
    `gcloud compute instance-groups managed set-target-pools` command.
  + Google App Engine
  * Components updated to 1.9.30.
    Please visit the following release notes for details:
  * Python - https://cloud.google.com/appengine/docs/python/release-notes
  * Java - https://cloud.google.com/appengine/docs/java/release-notes
  * Fixed a bug caused by uploading invalid file names for vm: true
    applications.
  + Compute
  * Subnetwork support has been promoted from alpha to beta. For more
    information see https://cloud.google.com/compute/docs/subnetworks.
- From version  0.9.89 (2015/12/02)
  + Breaking Changes
  * Removed flag `--container-ipv4-cidr` for
    `gcloud container clusters create`; please use `--cluster-ipv4-cidr`
    instead.
  * Renamed `gcloud alpha compute vpn-tunnels create --ike-networks` to
    `--local-traffic-selector`.
  * `gcloud alpha compute resource-views` commands will soon be removed.
    Please use `gcloud compute instance-groups unmanaged` commands instead.
  * `gcloud alpha compute replica-pools` commands will soon be removed.
    Please use `gcloud compute instance-groups` commands instead.
  + `gcloud` Core
  * Changed behavior of `gcloud init` git repository clone option. It now
    takes as input a path to the destination directory for the repository,
    rather than the parent directory of the repository destination.
  + BigQuery
  * Fixed failure in `gcloud alpha biquery query
    "select     * from ..."` command while displaying query results.
  + Compute
  * Fixed `gcloud alpha compute instances set-machine-type` failure when
    supplying custom cpu/custom memory, but no zone.
  * Added a new scope alias for Cloud Monitoring: `monitoring-write`. This
    scope is on by default in all new VMs.
  + Google Cloud DNS
  * Added `--replace-origin-ns` flag to `gcloud dns record-sets import`
    command to allow importing NS records.
  + Google Cloud Storage
  * Updated `gsutil` component to 4.16.
  + Google Container Engine
  * Updated kubectl to version 1.1.2.
  * Increased `gcloud container clusters create/delete` timeouts from 20m to
    30m.
  * Added `--subnetwork` flag to `gcloud container clusters create` to
    allow creation of container clusters can now be created in a Google
    Compute Engine subnetwork
    (https://cloud.google.com/compute/docs/subnetworks).
- From version  0.9.88 (2015/11/25)
  + Breaking Changes
  * The `gcloud preview app run` command has now been removed. Please use
    the bundled `dev_appserver.py` script directly instead.
  * App Engine: The 'version' and 'application' fields in module and
    configuration files are now illegal. Project name should instead be
    specified either by `gcloud config set project MY_PROJECT` or by
    setting the `--project` flag on individual command executions. Versions
    are generated automatically by default but can also be manually
    specified by setting the `--version` flag on individual command
    executions.
  + App Engine
  * Don't do runtime identification for custom runtimes during deploy. This
    fixes issue [#387]
    (https://code.google.com/p/google-cloud-sdk/issues/detail?id=387).
  * The `dev_appserver.py` script no longer requires the installation of
    all App Engine components. It will install only the necessary ones at
    run time. Fixes [#273]
    (https://code.google.com/p/google-cloud-sdk/issues/detail?id=273)
  + Core
  * Added the `gcloud components install` command.  This allows you to
    install missing components at the version of the SDK you currently have
    (it does not update your SDK installation).  `gcloud components update`
    should now only be used to update your SDK to the latest version.
  * Fixes [#293]
    (https://code.google.com/p/google-cloud-sdk/issues/detail?id=293)
    related SSL certificate validation issues.
  * Use zsh builtins in path.zsh.inc for faster/cleaner shell startup.
* Mon Nov 30 2015 rjschwei@suse.com
- Provide a better message for "components" sub command being disabled
  + Added patch disableSelfUpdate.patch
* Sat Nov 21 2015 rjschwei@suse.com
- Remove patches:
  + gsutil_respectBotoCfgKeyword.patch
  + gsutilHideDeps.patch
  + gcutilHideDeps.patch
  + hideImplicitVersionMgmt.patch
  + gsutil_noVersioCheckOrUpdate.patch
  + gcutilNoInternalVersionCheck.patch
  + bqHideDeps.patch
- Update to version 0.9.87  (bsc#954690)
  [#]## Compute
  * `gcloud alpha compute instances create` now supports --custom-cpu and
  - -custom-memory flags to specify custom machine types.
  [#]## Dataproc
  * Added `gcloud beta dataproc clusters diagnose` command. See
    <https://cloud.google.com/dataproc/support/diagnose-command> for
    more info.
  [#]## Google Container Engine
  * Updated kubectl to version 1.1.1.
  * 0.9.86 (2015/11/11)
  [#]## App Engine
  * Generated node.js Dockerfiles now add the full application context before
    running install hooks.
  * For Google App Engine Node.js runtimes, install requested version of node
    prior to doing an npm install.
  [#]## Compute
  * `gcloud beta compute instances set-machine-type` has been promoted
    from alpha to beta,
  * From 0.9.85 (2015/11/04)
  * `gcloud alpha compute networks create` now requires --mode flag.
  (Backwards incompatible change)
  [#]## App Engine
  * Added the --output-directory option to gen-repo-info-file command.
    This option supersedes --output-file, which is deprecated and will
    be removed in a future release.
  * Improved error message when specified yaml file is not found.
  [#]## Compute
  * Launching `gcloud alpha compute networks subnets`.
  * `gcloud compute alpha instance-templates` and `instances` now support
    subnetworks.
  * New flag --ike-networks in `gcloud alpha compute vpn-tunnels create`.
  * `gcloud compute ssh` now passes through the exit code of the ssh
    command. This fixes issue [#146 ]
    (https://code.google.com/p/google-cloud-sdk/issues/detail?id=146).
  [#]## Misc. Changes
  * Gracefully handle socket timeouts while checking for Google Compute
    Engine metadata server. This fixes issue [#339]
    (https://code.google.com/p/google-cloud-sdk/issues/detail?id=339).
  * From 0.9.84 (2015/10/28)
  [#]## App Engine
  * Due to PageSpeed service deprecation, user will receive a warning when
    deploying a new version to App Engine.
  * Implemented fingerprinting support for Java.
  * The gen-config flag now generates only app.yaml for the matching
    runtime by default, you must use the --custom flag to generate an
    app.yaml with a runtime of "custom" and Dockerfile (and other configs).
  [#]## Compute
  * GA support for https load balancing features.
  * Deprecated --clear-target-pool flag from compute instance-groups managed
    set-target-pools command.
  [#]## Windows support
  * Windows Installer can now take a /logtofile flag to write installation
    logs to file CloudSDKInstall.log located in the same directory.
  * Windows installer now displays an error message when the installation
    does not succeed.
  [#]## Command Line Interface support
  * The [page=N] table format attribute prints one or more tables of at
    most N rows. Use this to view paged server data as it arrives at
    the client.
  * From 0.9.83 (2015/10/21)
  [#]## App Engine
  * In a future release, the `gcloud preview app deploy` command will
    no longer support deploying multiple modules in the same invocation.
  [#]## Compute
  * Ubuntu 14.10 is end of life: https://wiki.ubuntu.com/Releases
  * Fixed external issue [#291]
    (https://code.google.com/p/google-cloud-sdk/issues/detail?id=291),
    related to handling network addresses on Windows.
  [#]## Container Engine
  * `gcloud container clusters list` now displays the current number of nodes
    for the cluster.
  [#]## Windows support
  * When running Cloud SDK tools from PowerShell the `gcloud-ps.ps1` wrapper
    scripts now can be used which no longer call to `cmd.exe`. Using
    `gcloud-ps`, complex arguments can be passed without escaping for
    Windows command line. Using `gcloud`, the following command would be
    correctly escaped when running gcloud in PowerShell:
    gcloud fun --arg='"test ^< 123"'
    With the new `gcloud-ps`, the same command can be simply written as:
    gcloud-ps fun --arg='test < 123'
    Permissions to run PowerShell scripts must be given to PowerShell
    before these will work. Permissions can be changed with
    `"Set-ExecutionPolicy RemoteSigned"`.
  * From 0.9.82 (2015/10/14)
  [#]## App Engine
  * The App Engine Admin API is now the default path for deployments in the
    `gcloud preview app deploy` command. This transition should be
    transparent, but if you experience any issues and would like to
    revert to the old behavior, please run `gcloud config set
    app/use_appengine_api false`.
    See <https://cloud.google.com/appengine/docs/admin-api/> for more
    information about this API.
  * With `env: 2`, valid python runtimes are `python` and `python-compat`.
  * Implemented fingerprinting support for python.
  [#]## Container Engine
  * `gcloud container clusters create`: The flag `--container-ipv4-cidr` has
    been deprecated; `--cluster-ipv4-cidr` should be used instead.
  [#]## SQL
  * `gcloud beta sql operations describe` and
    `gcloud beta sql operations wait` no longer need `--instance`
    flag (`gcloud beta sql operations list` still does).
  * Fixed issue with `gcloud sql instances clone` when `--bin-log-file-name`
    and `--bin-log-position` are set.
    (<https://code.google.com/p/google-cloud-sdk/issues/detail?id=201>).
  * From 0.9.81 (2015/10/07)
  [#]## Breaking Changes
  * If you are using a service account to run commands under
    `gcloud preview app`, you must enable the "App Engine Admin API" in the
    Developers Console (<https://console.developers.google.com>; navigate to
  * *APIs and Auth > APIs**).
  * In a future Cloud SDK release, deployments that promote the new version to
    receive all traffic will stop the previous version by default.
    To keep the current behavior, pass the `--no-stop-previous-version`
    flag, or run the following command:
    $ gcloud config set app/stop_previous_version false
  * Removed `app get-resource-limits` command.
  [#]## App Engine
  * App Engine components updated to 1.9.27. Please see the following release
    notes for details:
  * Python: <https://cloud.google.com/appengine/docs/python/release-notes>
  * Java: <https://cloud.google.com/appengine/docs/java/release-notes>
  * The `gcloud preview app deploy` command now requires that users specify or
    omit the runtime: field from app.yaml if a Dockerfile is also specified.
  * The `gcloud preview app deploy` command now supports the "engines" field
    in package.json for node.js applications.
  [#]## Misc. Changes
  * Windows Installer has an option to run `gcloud init` after the
    installation finishes.
  * From 0.9.80 (2015/09/30)
  * `gcloud app`
  * Soon, deployments will set the deployed version to receive all traffic
    by default.  To keep the current behavior, use the `--no-promote` flag
    or run the following command:
    $ gcloud config set app/promote_by_default false
    To adopt the new behavior early, use the `--promote` flag or run the
    following command:
    $ gcloud config set app/promote_by_default true
  * The `--set-default` flag is deprecated. Please use the `--promote` flag
    instead.
  * In a future Cloud SDK release, deployments that promote the new version
    to receive all traffic will stop the previous version by default.  To
    keep the current behavior, pass the `--no-stop-previous-version` flag,
    or run the following command:
    $ gcloud config set app/stop_previous_version true
  * The `app run` command is deprecated and will soon be removed.  Please
    use dev_appserver (found in the same directory as the `gcloud command)
    instead.
  * The `gcloud preview app modules download command` is deprecated, and
    will be removed soon.
  * The Windows installer has an option to run `gcloud init` after the
    installation finishes.
  * The `preview` component has been removed.
  * The `gcloud preview app` commands remain available as usual and
    are still shipped through the `app` component.
  * Please use `gcloud compute instance-groups unmanaged` instead
    of `gcloud preview instance-groups`.  Note that you will need to
    modify some command invocations when switching to the non-preview
    commands.
  * Please use `gcloud compute instance-groups managed` instead of
    `gcloud preview managed-instance-groups`.  Note that you will need to
    modify some command invocations when switching to the non-preview
    commands.
  * All Google Compute User Accounts commands have moved to beta.
  * Deployment-manager list commands now support pagination.
  * Minor bug fixes.
  * From 0.9.79 (2015/09/23)
  * The following commands have been promoted from beta to GA:
  * gcloud config configurations ...
  * gcloud source repos clone
  * gcloud beta init. Old `gcloud init` behavior has been removed, and
    partially replaced by new gcloud init or directly via gcloud source
    repos clone.
  * Release gcloud beta dataproc.
  * The --env-vars flag in gcloud preview app deploy has been removed.
  * Automatic ssh key generation respects the --quiet flag.
  * The --format flag now supports extended format expressions. For
    details run
    $ gcloud topic formats.
  * Most commands now document the positive Boolean --FLAG form and accept
  - -no-FLAG to disable. For the past few releases --log-http accepted an
    optional true/false value. It has been restored to its original definition
    of being a Boolean flag that has no value.
  * `gcloud sql` operations are now automatically retried for 2s in case of
    HttpException: The Cloud SQL instance operation does not exist.
  * Update gcloud's kubectl from 1.0.5 to 1.0.6.
  * Deprecate `gcloud preview app get-resource-limits`.
  * From 0.9.78 (2015/09/16)
  * App Engine components updated to 1.9.26. Please visit
    <https://code.google.com/p/googleappengine/wiki/SdkReleaseNotes> for
    details.
  * Increase the default boot disk size for remote build VMs in
    `gcloud preview app deploy`.
  * The `--instance` flag to the `gcloud preview app modules set-managed-by`
    command now takes an instance name instead of an index.
  * The V1Beta4 API for sqladmin can now be accessed through the
    `gcloud beta sql` surface.
  * Usability enhancements for `gcloud beta init` and named configurations.
  * From 0.9.77 (2015/09/09)
  * gcloud preview logging is now gcloud beta logging.
  * Update kubectl to version 1.0.5
  * Windows Cloud SDK installer improvements:
  * Now allows changing the installation mode. You can choose between a
    "current user" installation and an "all users" installation.
  * Now has an uninstaller and writes "Add/Remove Programs" uninstall
    entries.
  * Removal of unsupported --env-vars argument from gcloud preview app deploy.
  * gcloud compute instance groups: Allow --named-ports flag to be empty and
    clean named ports in set-named-ports commands.
  * Change in gcloud compute backend-services: introduce new flag
  - -instance-group which takes advantage of new Instance Groups API.
  * From 0.9.76 (2015/09/02)
  * Update gsutil component to 4.14.
  * Resource views commands have moved from preview to alpha. Please
    use `gcloud alpha compute resource-views` in place of
    `gcloud preview resource-views`.
  * Replica pool commands have moved from preview to alpha. Please use
    `gcloud alpha compute replica-pools` in place of
    `gcloud preview replica-pools`.
  * `gcloud beta source repo` was renamed to `gcloud beta source repos`
  * Created google-cloud-sdk-announce@googlegroups.com
    <https://groups.google.com/d/forum/google-cloud-sdk-announce> email
    group to announce new releases and other important information.
  * 'gcloud alpha init' command is now also in beta.
  * Add target size of managed instance group for "compute instance-groups
    managed list" command.
  * Fixed the removal of platform-specific components when running `gcloud
    components remove`.
  * Fixed a bug related to checking for SDK updates when the SDK is
    installed as root (like on Debian Compute Engine images).
  * Affected users should now see less frequent update messages and overall
    improved gcloud performance
  * `gcloud preview app deploy` won't update local images automatically
    anymore.
  * From 0.9.75 (2015/08/26)
  * Container Engine
  * Container Engine GA commands available under `gcloud container`.
  * `gcloud beta container get-credentials` now takes cluster name as
    argument instead of `--cluster` flag for consistency with other
    commands.
  * Added `gcloud alpha container clusters update <cluster>
  - -cloud-monitoring=<val>` command.
  * New release notes are printed on upgrade. (This won't take effect until
    an upgrade from this version to a later version.)
  * New `gcloud alpha genomics variantsets export` command.
  * Commands promoted from `gcloud alpha` to `gcloud beta`:
  * `gcloud beta config configurations ...`
  * `gcloud beta sources clone`
  * Improvements in error reporting and default output formatting.
  * From 0.9.74 (2015/08/19)
  * New list and import commands under `gcloud alpha genomics variants`.
  * Removed `--remote` flag. Instead, please use the `--docker-build=remote`
    flag (or use `--docker-build=local` to force a local build).
  * In this release, Docker builds are hosted by default. To opt-in to
    the old behavior, please use the `--docker-build=local` flag.
  * 0.9.73 (2015/08/12)
  * gcloud sql instances create default to MySQL 5.6
  * gcloud beta container get-credentials renamed to gcloud beta container
    clusters get-credentials
  * New commands
  * gcloud beta projects ...
  * gcloud alpha genomics callsets ...
  * gcloud beta emulators datastore ...
  * gcloud beta container get-server-config
  * gcloud alpha config configurations
  * From 0.9.72 (2015/08/05)
  * gcloud compute
  * initial surface changes for the backend-bucket.
  * `instance-groups set-named-ports`: introduced a new flag
    `--named-ports NAME:PORT,[NAME:PORT,...]` - no need to specify names
    and ports in separate flags.
  * gcloud preview app deploy
    Deprecate `--remote` flag in preparation for hosted Docker builds by
    default. Instead, please use the `--docker-build={remote,local}` flag.
    The default is still a local Docker build; in two releases, the default
    will switch to a hosted build.
  * New gcloud alpha genomics operations {list, cancel, describe} commands
  * From 0.9.71 (2015/07/29)
  * Launching `gcloud alpha pubsub` commands.
  * Moved `gcloud preview rolling-updates` to
    `gcloud alpha compute rolling-updates`.
  * `gcloud alpha compute disks resize` command enabling resizing of
    persistent disks.
  * Beta launch of customer supplied encryption keys for Compute Engine.
  * Updated kubectl to 1.0.1.
  * `gcloud alpha container` commands now target Container Engine v1 API.
    Options for `gcloud alpha container clusters create` updated accordingly:
  * `--user` renamed to `--username`
  * `--cluster-api-version` removed. Cluster version is not selectable in
    v1 API; new clusters always created at latest supported version.
  * `--image` option removed. Source image not selectable in v1 API;
    clusters are always created with latest supported ContainerVM image.
    Note that using an unsupported image (i.e. not ContainerVM) would
    result in an unusable cluster in most cases anyway.
  * Added `--no-enable-cloud-monitoring` to turn off cloud monitoring
    (on by default).
  * Added `--disk-size` option for specifying boot disk size of node vms.
  * App Engine components updated to 1.9.24. Please visit
    <https://code.google.com/p/googleappengine/wiki/SdkReleaseNotes> for
    details.
    For several months on the Managed VMs team we've been testing a new
    mode of `dockerless` local development on gcloud that makes developing
    a module for Python, Java and Go users similar to development of
    regular App Engine applications. This new mode relaxes the sandbox
    constraints present in the devappserver for `vm: false` applications,
    and does not require Docker to be installed.
    You can currently opt-into this behavior by setting
    GAE_LOCAL_VM_RUNTIME=1; In this release of the Cloud SDK, we will be
    making this behavior the default for Managed VM users who are using
    gcloud.
    You can still opt-out of this behavior by setting: GAE_LOCAL_VM_RUNTIME=0.
    For custom runtime users, if you are relying on the local Development
    Server to build your application, will now need to pass the
    `--custom-entrypoint` flag to `gcloud preview app run` to provide
    gcloud with the correct command to call.
    This does not affect users developing for non-managed VMs, or for
    users who are not using gcloud."
  * Bug fixes for:
  * `gcloud preview app deploy` file paths issue on Windows.
  * `gcloud compute instance-groups managed wait-until-stable` periodic user
    prompting for target zone.
  * From 0.9.70 (2015/07/22)
  * Add `gcloud compute instance-groups` commands.
  * Move `gcloud beta deployment-manager` commands to general availability as
    `gcloud deployment-manager` and update to use the v2beta3 API. This change
    does not alter the gcloud surface for users of the deployment-manager
    component.
  * Update kubectl to 1.0.0.
  * `gcloud alpha genomics` commands now use the genomics V1 API. The
  - -project-number flag for `dataset create` and `dataset list` is now
    obsolete. The configured --project-id is used instead and can be
    overridden with the --project-id flag.
  * Fix hang on errors in `gcloud preview app deploy`.
  * From 0.9.69 (2015/07/15)
  * Update kubectl to 0.20.2.
  * Fix an authentication issue with 'gcloud docker' affecting docker version
    1.7.0 and later.
  * Remove `gcloud preview dm-v2` command group.
  * Remove `gcloud preview deployment-manager` command group
    (`gcloud beta deployment-manager` still exists; see
    <https://cloud.google.com/sdk/#install-version> if you want to pin your
    installation to an old version).
  * Bug fixes.
  * From 0.9.68 (2015/07/08)
  * Deprecated gcutil tool is no longer distributed with Cloud SDK.
    It is still available via <https://cloud.google.com/compute/docs/gcutil>.
  * Added support for Container engine BETA commands under the
    `gcloud beta container` command group.  Existing `gcloud alpha container`
    commands are unchanged.
  * The standalone App Engine SDKs are no longer distributed through the
    Cloud SDK.
  * App Engine functionality can still be used through the
    `gcloud preview app` command group.
  * The gae-java, gae-python, gae-php, and gae-go components no longer
    exist in the component manager.
  * If you need to use appcfg or dev_appserver directly, these are still
    available in the App Engine SDK downloads that can be found here:
    <https://cloud.google.com/appengine/downloads>
  * Bug fixes.
  * From 0.9.67 (2015/07/01)
  * App Engine components updated to 1.9.23. Please visit
    <https://code.google.com/p/googleappengine/wiki/SdkReleaseNotes> for
    details.
  * Added the "gen-config" command to app surface to generate configuration
    files for node.js apps.
  * New `compute instance-groups unmanaged` commands group for Instance
    Groups which are not managed by Instance Group Manager
  * Moved `gcloud beta sql instances connect` to `gcloud beta sql connect`.
  * Smarter polling while waiting for SQL operations to finish, reducing the
    number of requests sent to the server.
  * Linux/Mac install script disables prompts if there is no controlling tty.
  * Linux/Mac install script now properly detects zsh and ksh RC files.
  * Bug fixes.
  * From 0.9.66 (2015/06/24)
  * New commands
  * `gcloud alpha compute instances set-machine-type` for managing types
  * `gcloud topic` for supplementary help topics.
  * `gcloud deployment-manager deployments delete` prompt defaults to false.
  * From 0.9.65 (2015/06/17)
  * Fixes `reset-windows-password` on Windows if `openssl` is present on the
    path.
  * `gcloud compute reset-windows-password` is now available as a GA command.
  * Prevent creation of a user that matches the machine name on Windows.
  * gsutil now runs properly from not-default drive letters on Windows.
  * kubectl updated to 0.18.1.
  * `gcloud preview docker` moved to `gcloud docker`.
  * From 0.9.64 (2015/06/10)
  * New commands
  * `gcloud beta compute scp` for secure copy.
  * `gcloud alpha genomics` commands (on datasets).
  * `gcloud alpha source list` to lists project repositories.
  * kubectl will no longer be installed by default.
  * Bug fixes for https load balancing.
  * The help pager is $PAGER or less(1) if available, otherwise a
    builtin pager.
  * Update of gsutil component to version 4.13.
  * From 0.9.63 (2015/06/03)
  * 2x faster command load times.
  * Fix to allow `preview app` to use oauth service accounts
    <https://code.google.com/p/google-cloud-sdk/issues/detail?id=133>
  * From 0.9.62 (2015/05/27)
  * Not released.
  * From 0.9.61 (2015/05/20)
  * New kubectl component (installed by default)
  * Internal improvements to gcloud preview app deploy; includes changes to
    command output.
  * `gcloud preview projects` moved to `gcloud alpha projects`
  * Tab completion for `gcloud compute ssh`
  * From 0.9.60 (2015/05/13)
  * VPN moved to GA.
  * Preemptible VM support.
  * Bug fixes.
  * From 0.9.59 (2015/05/06)
  * Bug fixes.
  * From 0.9.58 (2015/04/29)
  * gcloud alpha bigquery launch.
  * Better error reporting in Customer Supplied Encryption Key files.
  * Bug fixes.
  * From 0.9.57 (2015/04/22)
  * gcloud beta deployment-manager launch.
  * gcloud app new deployment behavior.
  * deploy and run commands no longer take directories, only take a list of
    explicit yaml files.
  * gcloud beta compute reset-windows-password, support for new authentication
    scheme on Windows guest agent versions 3.0.0.0 and later.
  * Bug fixes.
  * From 0.9.56 (2015/04/15)
  * Bug fixes.
  * from 0.9.55 (2015/04/8)
  * New and improved gcloud dns surface including:
  * Transactions for scriptable editing of record-sets.
  * Importing record-sets from zone files and yaml files.
  * Exporting record-sets to zone files and yaml files.
  * VPN commands surfaced under gcloud compute.
  * Dataflow CLI commands launched under gcloud alpha!
  * From 0.9.52 (2015/03/18)
  * Bug Fixes.
  * From 0.9.51 (2015/03/11)
  * Bug Fixes.
  * From 0.9.50 (2015/03/04)
  * Introducing the `gcloud beta ...` command group
  * Existing gcloud commands will be replicated under this new group, but
    use the beta version of their API instead of the GA version.
  * New command behavior and features that are beta only will first appear
    under this group until the feature gets promoted to general
    availability.
  * Run `gcloud components update beta` to access the new commands, or it
    will be automatically installed for you on first run attempt.
  * `gcloud beta compute ...` is now available, using the compute 'beta' API.
    Cloud VPN.  See <https://cloud.google.com/compute/docs/vpn>
    for details.
  * Release of `gcloud compute instances move` and
    `gcloud compute disks move`.
  * From 0.9.49 (2015/02/25)
  * The Google Container Registry is now used by default for deployment of
    Managed VM applications. See here for more information:
    <https://cloud.google.com/tools/container-registry/>
  * We've increased the speed of the "image push" phase of Managed VM
    deployments.
  * The heavy lifting of retrieving the Go toolchain has been moved into the
    base Go Docker image which dramatically reduces the bandwidth consumed
    locally when running and deploying your images. You must delete your
    Dockerfile to pick up the changes.
  * We've fixed several bugs related to port forwarding in the local
    devappserver.
  * From 0.9.48 (2015/02/18)
  * A bug fix for running setup-managed-vms multiple times when using
    the Google Container Registry
  * From 0.9.47 (2015/02/11)
  * Bug fixes that allow tab completion to work for components in preview.
  * GCloud now auto installs components based on command execution.
  * From 0.9.46 (2015/02/04)
  * We've made significant improvements to the stability and speed of
    deploying Managed VMs by leveraging the new Google Container Registry.
    See this post for details on how to try it out today:
    <https://groups.google.com/forum/#!topic/google-appengine/c543NHZGhKM>
  * From 0.9.45 (2015/01/28)
  * Several bug fixes in the Dockerfile generated for the 'go' runtime.
    Delete the Dockerfile in your application directory and the Cloud SDK
    will copy the updated Dockerfile on your next deployment.
  * Several bug fixes related to flakiness in the setup-managed-vms command.
* Sat Jan 31 2015 rjschwei@suse.com
- Add patches:
    + gsutil_noVersioCheckOrUpdate.patch
    + gsutil_respectBotoCfgKeyword.patch
    + hidePathMangeling.patch
  Remove patches:
  - gcloudFixPath.patch
  - gsutilSupportBotoCfgKeyword.patch
- Update to version 0.9.44   bnc#915479
  + Fixes applied to the google/appengine-gobase image for managed VMs.
  + Tab completion for gcloud SQL commands.
  + Support added for authenticating service accounts with JSON keys.
    If using JSON keys, PyOpenSSL is no longer a dependency.
  + Suport for local ssds in instance templates for gcloud compute.
  + Progress Bars.
  + Compute Instances start/ stop commands.
  + Bug Fixes.
  + Added support for local SSD.
  + Added support for Google Compute Engine Instance Templates in
    compute component.
  + Overhaul of 'gcloud sql'
    ~ Updated the output for all commands.
    ~ Updated usage for 'gcloud sql ssl-certs create'.
  + Added support for creating and maintaining Cloud SQL read replica instances.
    ~ Added --master-instance-name property that can be set during replica
    creation to indicate the replication master for the read replica instance.
    ~ Added --enable-database-replication, --no-enable-database-replication
    flags that can be used to start, stop replication for the read replica
    instance.
    ~ Added 'promote-replica' command that promotes a read replica instance into
    a stand-alone Cloud SQL instance.
  + Added several new features to the compute component:
    ~ Implemented new subcommands for interacting with HTTP load balancing:
  - gcloud compute url-maps add-host-rule
  - gcloud compute url-maps add-path-matcher
  - gcloud compute url-maps remove-host-rule
  - gcloud compute url-maps remove-path-matcher
  - gcloud compute url-maps set-default-service
    ~ Added support for automatically generating initial Windows username and
    password when creating a virtual machine instance from a Windows
    image or a disk initializaed from a Windows image.
    ~ Added a new scope alias for Cloud SQL administration: 'sql-admin'.
  + The compute component is now in General Availability.
    ~ Added new 'compute/zone' and 'compute/region' properties that
    can be used to set a default zone and region. To set the
    properties, run 'gcloud config set compute/zone ZONE' and 'gcloud
    config set compute/region REGION'.
    ~ Added support for overriding disk auto-deletion during instance
    deletion.
    ~ Updated the output of commands that mutate resources to be more
    human-friendly. The --format flag can be used for more verbose
    output.
    ~ Replaced all 'get' subcommands with 'describe' subcommands (e.g.,
    'gcloud compute instances get' has been replaced with 'gcloud
    compute instances describe').
    ~ Renamed the 'firewalls' collection to 'firewall-rules'.
    ~ Added support to the 'addresses' collection for interacting with
    global addresses.
  + Updated gcutil to 1.16.3 and various AppEngine runtimes to 1.9.7 binaries.
  + Support running several modules by gcloud app run and fixed output errors.
  + Limit gcloud upgrade nags to once per day.
  + Bring help files up to date (for example improved the documentation
    for DM 'templates create' and 'deployments create').
  + Added prompting for regions and zones to most subcommands of the
    compute component.
  + Added new subcommands to the compute component for adding and removing
    backends from backend services.
  + Added --ssh-flags to 'gcloud compute ssh' for passing additional flags
    to ssh.
  + Added image alias support for the --image flag in the compute component.
  + Added --shell mode to all gcloud commands
    ~ Type a partial command followed by '--shell' to drop into a sub shell
    at that point in the command tree.
    ~ Eg:
    $ gcloud compute --shell
    gcloud compute $ instances list
    gcloud compute $ copy-files ...
  + Updated gsutil to 4.3
  + Allow installed crcmod to be used by default with gsutil by enabling
    site packages
* Fri Jun 27 2014 rschweikert@suse.com
- Disable the Google built in "component" management and version upgrade
  mechanism
  + add hideImplicitVersionMgmt.patch
* Sat Jun 21 2014 rschweikert@suse.com
- Fix setup file to properly include package data embedded in
  googlecloudsdk package, previously *.json files were missing
* Tue Jun 17 2014 rschweikert@suse.com
- Remove debug print from setup.py
- Include templated html files as data files, these are used by the
  auth setup workflow
* Fri Jun  6 2014 rschweikert@suse.com
- Remove unnecessary dependency on python-oauth2
* Thu Jun  5 2014 rschweikert@suse.com
- Update to version 0.9.25
  + 'gcloud preview app deploy' and '... run' argument updates.
  + 'gcloud config *' argument updates.
  + Updated all AppEngine tools to 1.9.5
  - https://code.google.com/p/googleappengine/wiki/SdkReleaseNotes
  - https://code.google.com/p/googleappengine/wiki/SdkForJavaReleaseNotes
  + gcloud now has App Engine and Cloud Datastore integration.
  - Commands can be found under `gcloud preview app` and
    `gcloud preview datastore`
  + New `gcloud compute` tool for working with compute engine (RC)
  - Run `gcloud components update compute` to install
  - Run `gcloud help compute` for more information
  + Updated all AppEngine tools to 1.9.4
  - https://code.google.com/p/googleappengine/wiki/SdkReleaseNotes
  - https://code.google.com/p/googleappengine/wiki/SdkForJavaReleaseNotes
  + Added color to error and warning messages (on Linux and Mac)
  - To disable, run `gcloud config set disable_color true`
  + New 'gcloud help command'
  - Displays man style extended help for commands (where available).
  + New 'gcloud auth activate-service-account' command
  - Used to authenticate with gcloud using a service account key file.
  - See: https://developers.google.com/storage/docs/authentication#service_accounts
- Enable "big query" install and use
  + add patch bqHideDeps.patch
- Fix use of gcloud command
  + add patch gcloudFixPath.patch
* Thu Mar  6 2014 rschweikert@suse.com
- Update to version 0.9.18
  + Updated all AppEngine tools to 1.9.0
  - https://code.google.com/p/googleappengine/wiki/SdkReleaseNotes
  - https://code.google.com/p/googleappengine/wiki/SdkForJavaReleaseNotes
  + New 'gcloud init' command
  - Creates a local workspace for your project with a git clone of
    your Google hosted repository.
  + Updated gcutil to 1.14.0
  - Switched to new, single API call for creating a virtual machine instance
    with a root persistent disk.
  - Added new command, 'setinstancediskautodelete', that sets the
    auto-delete option for persistent disks attached to virtual
    machine instances.
  - Added support for specifying a disk size when creating a disk using
    a snapshot.
  - Decreased the time spent waiting for SSH keys to propagate
    during initial instance creation from 120 seconds to 10 seconds.
* Thu Mar  6 2014 rschweikert@suse.com
- Disable gcutil internal version check
- add patch: gcutilNoInternalVersionCheck.patch
* Thu Mar  6 2014 rschweikert@suse.com
- Support the new boto config option and recognize the "system"
  keyword. Set the certificates file to None to use the system
  implementation
- add patch: gsutilSupportBotoCfgKeyword.patch
* Thu Feb 27 2014 rschweikert@suse.com
- Add missing dependency to python-setuptools
* Thu Feb 27 2014 rschweikert@suse.com
- Include in SLE 12 (FATE #316168)
* Wed Feb 26 2014 rschweikert@suse.com
- Add missing package dependencies
* Wed Feb 26 2014 rschweikert@suse.com
- Remove the dependency on python-oauth2, this is only needed when using
  the oauth2client delivered with the sdk tarball. However, we use the
  already packaged version of the client google-api-python-client which
  does not have that dependency. Thus the dependency is superfluos.
* Mon Feb 24 2014 rschweikert@suse.com
- Fix the gcutilHideDeps.patch to hide requirements on python versions < 2.7
  this fixes build on SLE 11
* Mon Feb 24 2014 rschweikert@suse.com
- Use the setup.py code of the "integrated" gsutil and gcutil code
  the toplevel gsutil and gcutil commands are useless wrappers that play
  extremely stupid tricks with the path and other stuff.
- Add patch gsutilHideDeps.patch and gcutilHideDeps.patch to hide the
  hard dependencies for gsutil and gcutil, respectively
* Thu Feb 20 2014 rschweikert@suse.com
- Adjust version settings for obsoletes and provides
* Wed Feb 19 2014 rschweikert@suse.com
- Initial build
